/*====================================================================
 
 Objectweb Browser Framework
 Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
 Contact: openccm@objectweb.org
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 USA
 
 Initial developer(s): Jerome Moroy.
 Contributor(s): ______________________________________.
 
 ---------------------------------------------------------------------
 $Id: LoadTemplateAction.java,v 1.2 2004/04/14 09:43:14 rouvoy Exp $
 ====================================================================*/

package org.objectweb.util.browser.plugins.fractal.menu;

import org.objectweb.fractal.adl.Parser;
import org.objectweb.util.browser.api.MenuItem;
import org.objectweb.util.browser.api.MenuItemTreeView;
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.util.browser.gui.api.DialogAction;
import org.objectweb.util.browser.gui.api.DialogBox;
import org.objectweb.util.browser.gui.lib.BooleanBox;
import org.objectweb.util.browser.gui.lib.DefaultDialogBox;
import org.objectweb.util.browser.gui.lib.FileChooserBox;
import org.objectweb.util.browser.plugins.fractal.api.FractalBrowserConstants;
import org.objectweb.util.browser.plugins.fractal.lib.JFileChooserSingleton;

/**
 * This action allows to Load a template from the Parser.
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class LoadTemplateAction 
  implements MenuItem, 
             DialogAction 
{
    //==================================================================
    //
    // Internal states.
    //
    //==================================================================
    
    /** The name of the template to load. */
    protected FileChooserBox file_ = null;
    
    /** The boolean to indicate if a template is required. */
    protected BooleanBox withTemplate_ = null;
    
    /** The parser to use to load a template. */
    protected Parser parser_ = null;
    
    /** The TreeConfiguration to use to add the template. */
    protected TreeView treeView_;
    
    //==================================================================
    //
    // No constructor.
    //
    //==================================================================
    
    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================
    
    /**
     * Create a box containing all the box to specify all the params.
     */
    protected void createBox(DialogBox dialogBox) {
        file_ = new FileChooserBox("File",JFileChooserSingleton.getInstance(FractalBrowserConstants.FRACTAL_FILE_FILTER));
        dialogBox.addElementBox(file_);
        withTemplate_ = new BooleanBox("Type","Template","Component",true);
        dialogBox.addElementBox(withTemplate_);
    }
    
    //==================================================================
    //
    // Public methods for ExtendedActionListener interface.
    //
    //==================================================================
    
    /**
     * The action event.
     */
    public void actionPerformed(MenuItemTreeView e) throws Exception{
        treeView_ = e;
        parser_ = (Parser)e.getSelectedObject();        
        DialogBox dialog = new DefaultDialogBox("Load a template");      
        createBox(dialog);
        dialog.setValidateAction(this);
        dialog.show();
    }
    
    /**
     * @see org.objectweb.util.browser.api.MenuItem#isActive(org.objectweb.util.browser.gui.common.TreeView)
     */
    public int getStatus(TreeView treeView) {
        return MenuItem.ENABLED_STATUS;
    }
    
    //==================================================================
    //
    // Public methods for DialogAction interface.
    //
    //==================================================================
    
    /**
     * Executes an action.
     */
    public void executeAction() throws Exception {
        String fileName = file_.getFile().getName();
        String name = fileName.substring(0,fileName.lastIndexOf("."));
        if(withTemplate_.getValue())
            treeView_.getTree().addEntry(name+"Tmpl",parser_.loadTemplate(name,true));
        else
            treeView_.getTree().addEntry(name, parser_.loadTemplate(name,false));
    } 
    
}