/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

import java.awt.BorderLayout;
import java.io.File;
import java.io.IOException;
import java.net.MalformedURLException;
import java.util.jar.JarFile;

import javax.swing.JFrame;
import javax.swing.JSplitPane;

import org.objectweb.util.browser.core.api.StatusBar;
import org.objectweb.util.browser.core.api.ViewPanel;
import org.objectweb.util.browser.core.common.DefaultStatusBar;
import org.objectweb.util.browser.core.common.DefaultTreePanel;
import org.objectweb.util.browser.core.common.DefaultViewPanel;
import org.objectweb.util.browser.core.common.DynamicTree;
import org.objectweb.util.browser.plugin.java.reflect.JarFileStructure;

/**
 * 
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class Main {

    public Main(String configFile){        
        // Creates the main frame
        JFrame frame = new JFrame("Browser GUI");
        
        // Creates the view panel
        ViewPanel viewPanel = new DefaultViewPanel();
        
        // Creates the status bar
        StatusBar statusBar = new DefaultStatusBar();
        
        // Creates the tree
        DynamicTree tree = new DynamicTree();
                   
        // Configures the tree
        tree.setNewBrowserProperty(new String[]{configFile});
        tree.setTargetPanel(viewPanel);
        tree.setStatusBar(statusBar);

        // Populates the tree
        try {
            File f = new File("build/lib/reflect-plugin.jar");
            tree.addEntry(f.getName(), new JarFileStructure(new JarFile(f),f.toURL()),8);  
        } catch (MalformedURLException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }        
        
        // Configures the main frame
        frame.getContentPane().setLayout(new BorderLayout());
        frame.getContentPane().add(
            new JSplitPane(
                JSplitPane.HORIZONTAL_SPLIT,
                true,
                new DefaultTreePanel((DynamicTree)tree),
                ((DefaultViewPanel)viewPanel)),
            BorderLayout.CENTER);
        frame.getContentPane().add((DefaultStatusBar)statusBar, BorderLayout.SOUTH);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.pack();
        frame.setVisible(true);        
    }

    public static void main(String[] args){
        if(args.length != 0)
            new Main(args[0]);
    }

}
