/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.plugin.java.reflect;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JCheckBox;
import javax.swing.JPanel;

import org.objectweb.util.browser.gui.api.ValidateReport;
import org.objectweb.util.browser.gui.lib.AbstractElementBox;
import org.objectweb.util.browser.gui.lib.DefaultValidateReport;

/**
 *  
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class ClassVisibilityBox 
    extends AbstractElementBox {

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    protected ClassVisibilityConfig oldConfig_, newConfig_;


    //==================================================================
    //
    // Constructor.
    // 
    //==================================================================

    /**
     * Constructor with params
     */
    public ClassVisibilityBox() {
        this(null);
    }

    public ClassVisibilityBox(ClassVisibilityConfig config) {
        super(true);
        
        if(config!=null)
            oldConfig_ = config;
        else
            oldConfig_ = new ClassVisibilityConfig();
        newConfig_ = (ClassVisibilityConfig)oldConfig_.clone();
        
        Box mainBox = Box.createVerticalBox();
        
        Box treeInheritanceBox = Box.createHorizontalBox();
        treeInheritanceBox.add(Box.createHorizontalGlue());
        JPanel treeInheritancePanel = createHorizontalPanel("Tree Inheritance");
        treeInheritancePanel.add(createCheckBox("Tree inheritance", ClassVisibilityConfig.TREE_INHERITANCE));
        treeInheritancePanel.add(createCheckBox("Flat view", ClassVisibilityConfig.FLAT_VIEW));
        treeInheritanceBox.add(treeInheritancePanel);
        treeInheritanceBox.add(Box.createHorizontalGlue());
        
        mainBox.add(treeInheritanceBox);
        
        mainBox.add(Box.createVerticalStrut(10));
        
        Box classVisibilityBox = Box.createHorizontalBox();
        
        classVisibilityBox.add(Box.createHorizontalGlue());
        
        JPanel attributesPanel = createVerticalPanel("Attributes");        
        attributesPanel.add(createCheckBox("public", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.PUBLIC)); 
        attributesPanel.add(createCheckBox("protected", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.PROTECTED)); 
        attributesPanel.add(createCheckBox("private", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.PRIVATE));
        attributesPanel.add(createCheckBox("package", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.PACKAGE));
        attributesPanel.add(createCheckBox("static", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.STATIC));
        attributesPanel.add(createCheckBox("final", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.FINAL));
        attributesPanel.add(createCheckBox("display the type", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.TYPE));
        attributesPanel.add(createCheckBox("display declaring class", ClassVisibilityConfig.ATTRIBUTE + "." + ClassVisibilityConfig.DECLARING_CLASS));
        classVisibilityBox.add(attributesPanel);
        
        classVisibilityBox.add(Box.createHorizontalStrut(10));

        JPanel methodsPanel = createVerticalPanel("Methods");        
        methodsPanel.add(createCheckBox("public", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.PUBLIC)); 
        methodsPanel.add(createCheckBox("protected", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.PROTECTED)); 
        methodsPanel.add(createCheckBox("private", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.PRIVATE)); 
        methodsPanel.add(createCheckBox("package", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.PACKAGE));
        methodsPanel.add(createCheckBox("static", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.STATIC)); 
        methodsPanel.add(createCheckBox("final", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.FINAL));
        methodsPanel.add(createCheckBox("abstract", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.ABSTRACT));
        methodsPanel.add(createCheckBox("display the params", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.PARAMS));
        methodsPanel.add(createCheckBox("display the return type", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.RETURN_TYPE));
        methodsPanel.add(createCheckBox("display declaring class", ClassVisibilityConfig.METHOD + "." + ClassVisibilityConfig.DECLARING_CLASS));
        classVisibilityBox.add(methodsPanel);

        classVisibilityBox.add(Box.createHorizontalStrut(10));

        JPanel innerClassPanel = createVerticalPanel("Inner Classes");        
        innerClassPanel.add(createCheckBox("public", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.PUBLIC)); 
        innerClassPanel.add(createCheckBox("protected", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.PROTECTED)); 
        innerClassPanel.add(createCheckBox("private", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.PRIVATE)); 
        innerClassPanel.add(createCheckBox("package", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.PACKAGE));
        innerClassPanel.add(createCheckBox("static", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.STATIC));
        innerClassPanel.add(createCheckBox("final", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.FINAL));
        innerClassPanel.add(createCheckBox("abstract", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.ABSTRACT));
        innerClassPanel.add(createCheckBox("display declaring class", ClassVisibilityConfig.INNER_CLASS + "." + ClassVisibilityConfig.DECLARING_CLASS));
        classVisibilityBox.add(innerClassPanel);
        
        classVisibilityBox.add(Box.createHorizontalGlue());
        
        mainBox.add(classVisibilityBox);
        
        add(mainBox);        
    }

    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================

    protected JPanel createVerticalPanel(String title){
        JPanel panel = new JPanel();
        panel.setBorder(BorderFactory.createTitledBorder(title));
        panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));
        panel.setAlignmentY(TOP_ALIGNMENT);
        panel.setAlignmentX(LEFT_ALIGNMENT);
        return panel;   
    }

    protected JPanel createHorizontalPanel(String title){
        JPanel panel = new JPanel();
        panel.setBorder(BorderFactory.createTitledBorder(title));
        panel.setLayout(new BoxLayout(panel, BoxLayout.X_AXIS));
        panel.setAlignmentY(TOP_ALIGNMENT);
        panel.setAlignmentX(LEFT_ALIGNMENT);
        return panel;   
    }

    protected JCheckBox createCheckBox(String label, String name){
        JCheckBox checkBox = new JCheckBox(label); 
        checkBox.setSelected(newConfig_.get(name));
        checkBox.addItemListener(new ChangeState(name, checkBox)); 
        return checkBox;        
    }

    //==================================================================
    //
    // Public methods for ElementBox interface.
    //
    //==================================================================

    public ValidateReport validateBox() {
        return new DefaultValidateReport();
    }

    //==================================================================
    //
    // Public methods.
    //
    //==================================================================
    
    public ClassVisibilityConfig getConfig(){
        return newConfig_;
    }
    
    //==================================================================
    //
    // Inner classes.
    //
    //==================================================================
    
    private final class ChangeState
        implements ItemListener {
    
        protected String state_;
        protected JCheckBox checkBox_;
        
        public ChangeState(String state, JCheckBox checkBox){
            state_ = state;     
            checkBox_ = checkBox;
        }
       
        public void itemStateChanged(ItemEvent e) {
            newConfig_.put(state_, checkBox_.isSelected());
        }

    }
    
}

    