/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.api;

/**
 * Entries are non-mutable structures representing entries in contexts.
 *
 * An Entry is composed of a <code>&lt;name,value,context&gt;</code> tuple,
 * where name is an Object, value is an Object and 
 * context is the owner Context.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.2
 *
 */
public interface Entry 
{

    /**
     * Gets the value contained in the entry.
     *
     * This method does not update the value contained in the entry.
     *
     * @return The value contained in the entry.
     */
    public Object 
    getValue();

    /**
     * Gets the name of the entry.
     *
     * This method does not update the name of the entry.
     *
     * @return The name of the target entry, in the context it belongs to.
     *
     */
    public Object 
    getName();

    /**
     * Gets the context containing the entry,
     * if any, null otherwise.
     *
     * This method does not update the context containing
     * the entry.
     *
     * @return The context containing the entry,
     *         if any, null otherwise.
     *
     */
    public Context 
    getContext();

}