/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.api;

/**
 * Defines methods in order to populate and to manipulate the tree.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public interface Tree
{

    /**
     * Refresh the selected node.
     */
    public void 
    refresh();

    /**
     * Adds an object into the initial context.
     *  
     * @param name Name of the object
     * @param value The object to add
     */
    public void 
    addEntry(Object name, Object value);

    /**
     * Adds an object into the initial context and expands the node until a specific level if this one is a context.
     *  
     * @param name Name of the object
     * @param value The object to add
     * @param level The level (>0 for a specific level or <0 for all levels)
     */
    public void 
    addEntry(Object name, Object value, int level);
   
    /**
     * Refreshes the selected node name.
     * 
     * @param odlName The old name.
     * @param newName The new name.
     */
    public void 
    renameSelectedNode(String odlName, String newName);
}