/*====================================================================

Objectweb Browser framework
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.core.naming;

import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.api.Context;

/**
 * An initial entry is an object which has to be displayed into the initial context (at the root of the tree).
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class InitialEntry 
  implements Entry
{
    
    /** The name of the entry. */
    protected String name_;
        
    /** The value of the entry. */
    protected Object value_;
        
    /** The number of level to expand. */
    protected int level_;

    /**
     * Default constructor.
     * @param name The name of the entry.
     * @param value The value of the entry.
     */        
    public InitialEntry(String name, Object value){
        this(name, value, 0);
    }
     
    /**
     * Default constructor.
     * @param name The name of the entry.
     * @param value The value of the entry.
     * @param level The number of level to expand.
     */        
    public InitialEntry(String name, Object value, int level){
        name_ = name;
        value_ = value;
        level_ = level;
     }
    
    public Object getName(){
        return name_;    
    }
        
    public Object getValue(){
        return value_;   
    }

    public Context getContext(){
        return null;
    }

    public int getLevel(){
        return level_;
    }
}