/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.core.panel;

import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.api.Panel;
import org.objectweb.util.browser.core.common.AssociatedElementImpl;
import org.objectweb.util.browser.core.api.AssociatedPanel;
import org.objectweb.util.browser.core.api.BrowserProperty;
import org.objectweb.util.browser.core.api.PanelFactory;

/**
 * Implementation of AssociatedPanel API 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class AssociatedPanelImpl 
    extends AssociatedElementImpl 
    implements AssociatedPanel {

    /**
     * Constructs a AssociatedPanelImpl
     * @param loader The propertyLoader to use to load new configuration
     * @param tree The associated tree
     */
    public AssociatedPanelImpl(BrowserProperty loader) {
        super();
        context_ = new PanelPropertyContainer(loader);
    }

    /** 
     * Returns the menu associates to the node
     * Equivalent to a getMenu(node,false) call
     *
     * @param node The node 
     * @return The associated panel or null if no context is found
     */
    public Panel getPanel(Object node) {
        return getPanel(node, false);
    }

    /** 
     * Returns the panel associates to the node
     *
     * @param node The node 
     * @param disabledJavaLangObject If true, then java.lang.Object is not consider as a valid entry
     * @return The associated panel or null if no context is found
     */
    public Panel getPanel(Object node, boolean disabledJavaLangObject) {
        if (context_ != null) {
            Entry entry = context_.getRecursiveProperty(node);
            if (entry != null && !(entry.getName().toString().equals("java.lang.Object") && disabledJavaLangObject)) {
                PanelFactory panelFactory = (PanelFactory) entry.getValue();
                Panel nodeViewPanel = panelFactory.newPanel(node);
                return nodeViewPanel;
            }
        }
        return null;
    }
}
