/*====================================================================

Objectweb Browser Framework
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Jerome Moroy.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.util.browser.core.panel;

import java.awt.BorderLayout;
import java.awt.Color;

//import javax.swing.BoxLayout;
import javax.swing.BorderFactory;
import javax.swing.JPanel;
//import javax.swing.JScrollPane;

import org.objectweb.util.browser.api.Panel;
import org.objectweb.util.browser.api.Table;
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.util.browser.core.api.Decoder;
import org.objectweb.util.browser.core.common.AdminCustomization;
import org.objectweb.util.browser.core.common.DynamicTable;

/**
 * 
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>,
 *         <a href="mailto:Jerome.Moroy@lifl.fr">Jrme Moroy</a>
 * 
 * @version 0.1
 */
public class DefaultTablePanel 
  implements Panel {

    //==================================================================
    //
    // Internal state.
    //
    //==================================================================

    protected JPanel panel_;
    
    protected Table table_;

    protected AdminCustomization custom_;

    protected Decoder decoder_;

    //==================================================================
    //
    // Constructor.
    // 
    //==================================================================

    public DefaultTablePanel(Table table, AdminCustomization custom, Decoder currentDecoder){
        panel_ = new JPanel();
        panel_.setBackground(Color.white);
        panel_.setBorder(BorderFactory.createLineBorder(Color.black));
        table_ = table;
        decoder_ = currentDecoder;
        custom_ = custom;
        //panel_.setLayout(new BoxLayout(panel_, BoxLayout.Y_AXIS));
        panel_.setLayout(new BorderLayout());
    }

    public DefaultTablePanel(Table table, AdminCustomization custom){
        this(table, custom, null);
    }

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================

    //==================================================================
    //
    // Public methods for Panel interface.
    //
    //==================================================================

    public void selected(TreeView treeView) {
        if(table_!=null){
            DynamicTable dynamicTable = null;
            if(decoder_!=null)
                dynamicTable = new DynamicTable(decoder_);    
            else
                dynamicTable = new DynamicTable();
            dynamicTable.setAdminCustomization(custom_);
            String[] headers = table_.getHeaders(treeView);
            Object[][] values = table_.getRows(treeView);
            if(values!=null && values.length>0){
                dynamicTable.setData(headers,values);
                //panel_.add(new JScrollPane(dynamicTable));
                panel_.add(dynamicTable.getTableHeader(),BorderLayout.NORTH);
                panel_.add(dynamicTable,BorderLayout.CENTER);
            }
        }       
    }

    public JPanel getPanel() {
        return panel_;
    }

    public void unselected(TreeView treeview) {
        // Nothing to do
    }

}

    