/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.util.browser.gui.lib;

import java.util.Calendar;
import java.util.GregorianCalendar;

import java.awt.Color;
import java.awt.Dimension;
import javax.swing.JDialog;
import javax.swing.JTextArea;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.AbstractAction;

import org.objectweb.util.browser.gui.api.Console;

import java.awt.event.ActionEvent;

/**
 * This class defines a graphical console.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class DefaultDialogConsole 
    extends JDialog
    implements Console {

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================
    
    protected JTextArea textArea_ = null;

    protected Calendar calendar_ = null;

    //==================================================================
    //
    // Constructor.
    //
    //==================================================================

    /**
     * Default constructor
     */
    public DefaultDialogConsole(String title, boolean isModal){
        super();
        
        setModal(isModal);
        setTitle(title);
        getContentPane().add(createBox());
        setDefaultCloseOperation(javax.swing.WindowConstants.HIDE_ON_CLOSE);
        //setResizable(false); 
        pack();

        // Centers the frame
        Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        setLocation((screenSize.width - getWidth()) / 2, (screenSize.height - getHeight()) / 2);
    }
    
    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================
    
    /**
     * Adds the buttons into the buttons panel.
     * @param buttonBox The panel which will contain the buttons.
     */
    public void addButtons(Box buttonBox){
        buttonBox.add(new JButton(new ClearAction()));
        buttonBox.add(Box.createHorizontalStrut(10));
        buttonBox.add(new JButton(new HideAction()));
    }

    /**
     * Creates the console box.
     */
    protected Box createBox(){
        Box mainBox = Box.createVerticalBox();

        mainBox.add(Box.createVerticalGlue());
        
        textArea_ = new JTextArea(25,40);
        textArea_.setBorder(javax.swing.BorderFactory.createLineBorder(Color.black));
        textArea_.setEditable(false);
        textArea_.setLineWrap(true);

        mainBox.add(new javax.swing.JScrollPane(textArea_));

        mainBox.add(Box.createVerticalStrut(10));

        Box buttonBox = Box.createHorizontalBox();
        buttonBox.add(Box.createHorizontalGlue());
        addButtons(buttonBox);
        buttonBox.add(Box.createHorizontalGlue());
        mainBox.add(buttonBox);

        mainBox.add(Box.createVerticalStrut(10));
        mainBox.add(Box.createVerticalGlue());

        return mainBox;
        
    }

    protected String getNumber(int num){
        return (num>9)?("" + num):("0" + num);
    }

    protected String getCurrentDate(){
        calendar_ = new GregorianCalendar();
        StringBuffer theDate = new StringBuffer();
        theDate.append(calendar_.get(Calendar.YEAR));
        theDate.append("/");
        theDate.append(getNumber(calendar_.get(Calendar.MONTH) + 1));
        theDate.append("/");
        theDate.append(getNumber(calendar_.get(Calendar.DAY_OF_MONTH)));
        theDate.append(" - ");
        theDate.append((calendar_.get(Calendar.AM_PM)==0)?"AM":"PM");
        theDate.append(" ");
        theDate.append(getNumber(calendar_.get(Calendar.HOUR)));
        theDate.append(":");
        theDate.append(getNumber(calendar_.get(Calendar.MINUTE)));
        theDate.append(":");
        theDate.append(getNumber(calendar_.get(Calendar.SECOND)));
        return theDate.toString();    
    }
    
    //==================================================================
    //
    // Public methods for Console interface.
    //
    //==================================================================

    /**
     * Adds a message into the console.
     * @param message The message to display.
     */
    public void add(String message){
        textArea_.append("[" + getCurrentDate() + "] ");
        textArea_.append(message);
    }

    /**
     * Clears the contains of the console.
     */
    public void clear(){
        textArea_.setText("");
    }

    /**
     * Shows the console.
     */
    public void show(){
        super.show();
    }

    /**
     * Hides the console.
     */
    public void hide(){
        super.hide();
    }

    //==================================================================
    //
    // Protected classes for button actions.
    //
    //==================================================================
    
    protected class ClearAction 
        extends AbstractAction {

        public ClearAction(){
            super("Clear");
        }

        public void actionPerformed(ActionEvent e){
            clear();
        }

    }

    protected class HideAction 
        extends AbstractAction {

        public HideAction(){
            super("Close");
        }

        public void actionPerformed(ActionEvent e){
            hide();
        }
    }

}
