/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2002-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): Areski Flissi.

====================================================================*/

package org.objectweb.openccm.corba;

// Package dependencies
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;
import java.net.URL;
import java.net.URLConnection;
import java.net.InetAddress;
import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.MulticastSocket;
import java.net.SocketException;
import java.net.UnknownHostException;

/**
 * This class encapsulates the ORBacus CORBA::ORB singleton object.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * @version 0.3
 */

public abstract class TheORB
              extends TheORBSingleton
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    private TheORB()
    {
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     * Initialize the ORBacus CORBA::ORB singleton object.
     *
     * @param args The command line arguments.
     *
     * @return The command line arguments without ORBacus options.
     */
    public static String[]
    initialize(String[] args)
    {

        // Manage CORBA initial references provided as http URLs
        // or Multicast group address (e.g. 224.0.0.100)

        for (int i = 0; i < args.length; i++)
        {
            if (args[i].equals("-ORBInitRef"))
            {
                i++;
                String arg = args[i];
                int index = arg.indexOf('=');
                String location = arg.substring(index + 1);
                if (location.startsWith("http:"))
                {
                    try {
                        URL url = new URL(location);
                        URLConnection conn = url.openConnection();
                        BufferedReader in =
                            new BufferedReader(
                                new InputStreamReader(conn.getInputStream()));
                        String ior = in.readLine();
                        in.close();

                        // Store the IOR obtained from the HTTP server
                        // in the command line arguments.
                        args[i] = arg.substring(0, index) + '=' + ior;

                    } catch (IOException exc) {
                        exc.printStackTrace(System.err);
                    }
                } else if (location.startsWith("mcast:")) {

                    // Store the IOR obtained from the MULTICAST server
                    // in the command line arguments.
                    args[i] =
                        arg.substring(0, index) + '=' + TheORBSingleton.request_ior(location);
                }
            }
        }

        // Define system properties.
        java.util.Properties properties = System.getProperties();
        properties.put("org.omg.CORBA.ORBClass", "com.ooc.CORBA.ORB");
        properties.put(
            "org.omg.CORBA.ORBSingletonClass",
            "com.ooc.CORBA.ORBSingleton");

        // Parse specific ORBacus arguments.
        args = com.ooc.CORBA.ORB.ParseArgs(args, properties, null);

        // Initialize the CORBA::ORB.
        setORB(org.omg.CORBA.ORB.init(args, properties));

        return args;
    }

    /**
     * Destroy the CORBA::ORB singleton object.
     */
    public static void
    destroy()
    {
        getORB().destroy();
    }
}
