#! /bin/sh -f
# ====================================================================
#
# OpenCCM: The Open CORBA Component Model Platform
# Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
# Contact: openccm@objectweb.org
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
# USA
#
# Initial developer(s): Philippe Merle.
# Contributor(s): Christophe Demarey, Jerome Offroy, Briclet Frdric.
#
# ====================================================================
#
# Starting a demonstration.
#
# $1: demonstration name.
#
# ====================================================================

demo_name=$1

# =====================
# Compute Command Line.
# =====================

if [ $# -lt 1 ]
then
    echo "usage: start_java <demo_name> [--ots] [--trace] [--monolithic | --xml]"
    exit 1
fi

with_ots="false"
with_trace="false"
with_trader="false"
with_tracing="false"
xml="false"
run_id=cif
services_args=
services_list=
assembly_zip=archives/${demo_name}.aar

for arg in $@;
do
    case $arg in
    "--trace")
        with_trace="true"
        services_args="${services_args} --trace"
        services_list="${services_list} Trace "
        ;;
    "--ots")
        with_ots="true"
        services_args="${services_args} --ots"
        services_list="${services_list} Transactional "
        ;;
    "--tracing")
        with_tracing="true"
        services_args="${services_args} --tracing"
        services_list="${services_list} Tracing "
        ;;
    "--xml")
        xml="true"
        ;;
    "--monolithic")
        run_id=monolithic
        ;;
    "--trader")
        with_trader="true"
        ;;
    "-h")
        echo "usage: start_java <demo_name> [--ots] [--trace] [--tracing] [--monolithic | --xml ] [--trader]"
        exit 1
        ;;
    *)
    esac
done

# Ant compilation if needed.
#
if [ ! -f generated/idl/${demo_name}.idl -o ! -f archives/${demo_name}.aar ]
then
    ./build.sh
fi

# =================
# Install platform.
# =================

# Install the OpenCCM Platform.
#
ccm_install

# =======================
# Start the Name Service.
# =======================
# ns_start
# Obtain the IOR of the started Name Service.
#
ns_set http://164.27.213.140:8080/NameService.IOR
ior_NS=`ns_ior`


# ==========================================================
# Start a default main_node to use deployment functionnality.
# ==========================================================
node_start ClientNode
