package ist.coach.coachEmfServicesComponents.SnmpAdapterProviderComposition;

/**
 * @author administrator (digi@intracom.gr)
 *
 * Copyright (c) Intracom S.A., N.T., 2003
 */

import java.lang.*;
import java.lang.System;
import java.net.*;
import org.opennms.protocols.snmp.*;
import java.util.Vector;

import ist.coach.coachEmfServices.SnmpAdapter.SnmpApplicationError;
import ist.coach.coachEmfCommon.ExceptionMessages;

	public class SnmpProtocolConverter implements SnmpHandler{

		private int m_version = SnmpSMI.SNMPV2;
		private String m_community = "public";
		private int m_retries = 5;
		private int m_timeout = 180;
		private int m_port = 161;
		private String m_host = null;

		/*For SNMP walk only*/
		private boolean snmpWalkRequest;
		private String m_startOid = null;
		private SnmpObjectId m_stopAt = null;
		public Vector resultSet = null;

		/*For session timeout */
		private boolean agentResponded;

		private int commandType = -1;

		public SnmpProtocolConverter (
			int version,
			String community,
			int retries,
			int timeout,
			int port,
			String host,
			String startOid) {

				this.m_version = version;
				this.m_community = community;
				this.m_retries = retries;
				this.m_timeout = timeout;
				this.m_port = port;
				this.m_host = host;

				this.m_startOid = startOid;

				this.resultSet = new Vector();

		}

		public SnmpProtocolConverter (
			String host,
			String community,
			int port,
			String startOid) {

				this.m_version = SnmpSMI.SNMPV2;
				this.m_community = community;
				this.m_retries = 5;
				this.m_timeout = 500;
				//this.m_port = 161;
				this.m_port = port;
				this.m_host = host;
				this.m_startOid = startOid;

				this.resultSet = new Vector();
		}

		public void snmpInternalError(SnmpSession session,
			int err, SnmpSyntax pdu){

				System.out.println("An unexpected error occured with the SNMP Session");
				System.out.println("The error code is " + err);

				synchronized(session){
					session.notify();
				}
		}

		public void snmpTimeoutError(SnmpSession session,
			SnmpSyntax pdu) {

			System.err.println("The session timed out trying to communicate with the remote host");

			synchronized(session){
				session.notify();
			}

			this.agentResponded = false;
		}

		public void snmpGet(SnmpVarBind[] vblist)
		throws SnmpApplicationError {

			SnmpPeer snmpPeer = null;
			this.snmpWalkRequest = false;
			this.agentResponded = true;

			//clear all previous results
			resultSet.clear();

			try {
				snmpPeer = new SnmpPeer(InetAddress.getByName(this.m_host));
			}
			catch (UnknownHostException ue) {
				ue.printStackTrace();
				throw new SnmpApplicationError(ExceptionMessages.snmp_host_resolve_error);
			}

			snmpPeer.setPort(this.m_port);
			snmpPeer.setTimeout(this.m_timeout);
			snmpPeer.setRetries(this.m_retries);

			SnmpParameters parms = snmpPeer.getParameters();
			parms.setVersion(this.m_version);
			parms.setReadCommunity(this.m_community);

			SnmpSession session = null;

			try {
				session = new SnmpSession(snmpPeer);
			}
			catch (SocketException se) {
				se.printStackTrace();
				throw new SnmpApplicationError(ExceptionMessages.agent_create_error);
			}

			session.setDefaultHandler(this);

			SnmpPduRequest pdu = new SnmpPduRequest(SnmpPduPacket.GET, vblist);

			try {

				synchronized(session) {
					session.send(pdu);
					session.wait();
				}
			}
			catch (InterruptedException ie) {
				ie.printStackTrace();
			}
			finally {

				System.out.println("Closing!");

				session.close();

			}
		}

		public void snmpGetNext(SnmpObjectId oid)
		throws SnmpApplicationError {

			SnmpPeer snmpPeer = null;
			this.snmpWalkRequest = false;
			this.agentResponded = true;

			//clear all previous results
			resultSet.clear();

			try {
				snmpPeer = new SnmpPeer(InetAddress.getByName(this.m_host));
			}
			catch (UnknownHostException ue) {
				ue.printStackTrace();
				throw new SnmpApplicationError(ExceptionMessages.snmp_host_resolve_error);
			}

			snmpPeer.setPort(this.m_port);
			snmpPeer.setTimeout(this.m_timeout);
			snmpPeer.setRetries(this.m_retries);

			SnmpParameters parms = snmpPeer.getParameters();
			parms.setVersion(this.m_version);
			parms.setReadCommunity(this.m_community);

			SnmpSession session = null;

			try {
				session = new SnmpSession(snmpPeer);
			}
			catch (SocketException se) {
				se.printStackTrace();
				throw new SnmpApplicationError(ExceptionMessages.agent_create_error);
			}

			session.setDefaultHandler(this);

			SnmpVarBind [] vblist = {new SnmpVarBind(oid)};

			SnmpPduRequest pdu = new SnmpPduRequest(SnmpPduPacket.GETNEXT, vblist);

			try {

				synchronized(session) {
					session.send(pdu);
					session.wait();
				}
			}
			catch (InterruptedException ie) {
				ie.printStackTrace();
			}
			finally {

				System.out.println("Closing!");

				session.close();

			}
		}

		public void snmpWalk()
		throws SnmpApplicationError {

			SnmpPeer peer = null;
			this.snmpWalkRequest = true;
			this.agentResponded = true;

			//clear all previous results
			resultSet.clear();

			try {
				peer = new SnmpPeer(InetAddress.getByName(this.m_host));
			}
			catch (UnknownHostException eh) {
				eh.printStackTrace();
				throw new SnmpApplicationError(ExceptionMessages.snmp_host_resolve_error);
			}
			peer.setPort(this.m_port);
			peer.setTimeout(this.m_timeout);
			peer.setRetries(this.m_retries);

			SnmpParameters parms = peer.getParameters();
			parms.setVersion(this.m_version);
			parms.setReadCommunity(this.m_community);

			SnmpSession session = null;
			try {

				session = new SnmpSession(peer);
			}
			catch(SocketException e) {
				System.err.println("SocketException creating the SNMP session");
				System.err.println("SocketException: " + e.getMessage());
				throw new SnmpApplicationError(ExceptionMessages.agent_create_error);
			}

			session.setDefaultHandler(this);

			if (m_stopAt == null) {
				SnmpObjectId id = new SnmpObjectId(m_startOid);
				int[] ids = id.getIdentifiers();
				++ids[ids.length-1];
				id.setIdentifiers(ids);
				m_stopAt = id;
			}

			SnmpVarBind[]  vblist = { new SnmpVarBind(m_startOid) };
			SnmpPduRequest pdu = new SnmpPduRequest(SnmpPduPacket.GETNEXT, vblist);
			try {
				synchronized(session)
				{
					session.send(pdu);
					session.wait();
				}
			}
			catch(InterruptedException e) {

				e.printStackTrace();

						// do nothing
			}
			finally {

				System.out.println("Closing");
				session.close();
				//System.out.println("Got " + this.getV().size() + " results.");
			}
		}

		public void snmpSet(SnmpVarBind[] vblist)
		throws SnmpApplicationError {

			SnmpPeer snmpPeer = null;
			this.snmpWalkRequest = false;
			this.agentResponded = true;

			//clear all previous results
			resultSet.clear();

			try {

				snmpPeer = new SnmpPeer(InetAddress.getByName(this.m_host));
			}
			catch (UnknownHostException ue) {
				ue.printStackTrace();
				throw new SnmpApplicationError(ExceptionMessages.snmp_host_resolve_error);
			}

			snmpPeer.setPort(this.m_port);
			snmpPeer.setTimeout(this.m_timeout);
			snmpPeer.setRetries(this.m_retries);

			SnmpParameters parms = snmpPeer.getParameters();
			parms.setVersion(this.m_version);
			parms.setWriteCommunity(this.m_community);

			SnmpSession session = null;

			try {
				session = new SnmpSession(snmpPeer);
			}
			catch (SocketException se) {
				se.printStackTrace();
				throw new SnmpApplicationError(ExceptionMessages.agent_create_error);
			}

			session.setDefaultHandler(this);

			SnmpPduRequest pdu = new SnmpPduRequest(SnmpPduPacket.SET, vblist);

			try {

				synchronized(session) {
					session.send(pdu);
					session.wait();
				}
			}
			catch (InterruptedException ie) {
				ie.printStackTrace();
			}
			finally {

				session.close();

			}
		}

		public void snmpReceivedPdu(SnmpSession session,
			int cmd,
			SnmpPduPacket pdu){

			SnmpPduRequest req = null;

			if(pdu instanceof SnmpPduRequest){
				req = (SnmpPduRequest)pdu;
			}

			System.out.println("Error index: " + req.getErrorIndex());
			System.out.println("Error status: " + req.getErrorStatus());

			if(pdu.getCommand() != SnmpPduPacket.RESPONSE){
				System.err.println("Error: Received non-response command " +
					pdu.getCommand());

				synchronized(session){
					session.notify();
				}

				return;
			}

			if(req.getErrorStatus() != 0){
				System.out.println("End of mib reached");

				synchronized(session){
					session.notify();
				}
				return;
			}
			/* previous request was an snmp walk request */
			if (this.snmpWalkRequest == true) {

				SnmpVarBind vb = pdu.getVarBindAt(0);
				if (vb.getValue().typeId() == SnmpEndOfMibView.ASNTYPE ||
					(m_stopAt != null && m_stopAt.compare(vb.getName()) < 0)) {

					System.out.println("End of Mib reached");
					synchronized (session) {
						session.notify();
					}
					return;
				}

				this.resultSet.add(vb);

				System.out.println(vb.toString());

				SnmpVarBind[] vblist = { new SnmpVarBind(vb.getName())};
				SnmpPduRequest newReq = new SnmpPduRequest(SnmpPduPacket.GETNEXT, vblist);

				session.send(newReq);
			}
			/* previous request was not an snmp walk request */
			else {

				System.out.println("Pdu length: " + pdu.getLength());

				for (int i = 0; i < pdu.getLength(); i++) {
					//System.out.println(pdu.getVarBindAt(i).toString());
					this.resultSet.add(pdu.getVarBindAt(i));
				}

				synchronized (session) {
					session.notify();
				}

				return;
			}
		}

		public boolean agentResponded() {

			return this.agentResponded;
		}

}

