/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Areski Flissi.
Contributor(s): 

====================================================================*/

package org.objectweb.ccm.chat.cif;

//import org.objectweb.ccm.chat.*;

/**
 * This is the implementation of the OMG IDL3 chat::Server component type.
 *
 * This class inherits from the skeleton
 * generated by the OpenCCM's CIF to Java mapping generator.
 *
 * @author <a href="mailto:Areski.Flissi@lifl.fr">Areski Flissi</A>
 */

public class ServerImpl
     extends org.objectweb.ccm.chat.ServerSessionComposition.ComponentImpl
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    
    /** The name of the component. */
    private String name_;

    /** To refer to the GUI frame. */
    private java.awt.Frame frame_;
    /** To refer to the GUI user output area. */
    private java.awt.TextArea textArea_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    ServerImpl()
    {
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL Components::EnterpriseComponent
    //
    // ==================================================================

    /**
     * Complete the component configuration.
     *
     * @exception org.omg.Components.InvalidConfiguration
     *            Thrown if the configuration is invalid.
     */
    public void
    configuration_complete()
    throws org.omg.Components.InvalidConfiguration
    {
        // Checks if the configuration is not completed.
        if(name_ == null)
            throw new org.omg.Components.InvalidConfiguration();

        System.out.println("================================");
        System.out.println("Welcome to OpenCCM's Chat server");
        System.out.println("================================");
    }

    // ==================================================================
    //
    // Methods for the OMG IDL org.omg.Components.SessionComponent
    //
    // ==================================================================

    /**
     * Container callback to signal that the component is removed.
     *
     * @throw org.omg.Components.CCMException For any problems.
     */
    public void
    ccm_remove()
    throws org.omg.Components.CCMException
    {
        // Release the associated frame.
		//frame_.dispose();
	 	frame_ = null;
    }

    // ==================================================================
    //
    // Methods for OMG IDL chat::CCM_NamedComponent_Executor
    //
    // ==================================================================

    /**
     * The mutator method for the attribute name.
     *
     * @param n The name.
     */
    public void
    name(String n)
    {
        name_ = n;

		if (frame_ != null)
			frame_.setTitle(name_ + "'s Server GUI");
    }
    /**
     * The accessor method for the attribute name.
     *
     * @return The name.
     */
    public String
    name()
    {
        return name_;
    }

    // ==================================================================
    //
    // Methods for OMG IDL chat::CCM_Service
    //
    // ==================================================================

    /**
     * The display operation of the chat::Service interface.
     *
     * @param text The text to display.
     */
    public void
    display(String text)
    {
        // Puts the text into the text area.
        //textArea_.append(text + "\n");
		System.out.println(text);
        // Pushes an event to all connected consumers.
        get_context().push_to_consumers( new TextEventImpl(text) );
    }
}

