/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Areski Flissi.
Contributor(s): 

====================================================================*/

package org.objectweb.ccm.filetransfer.cif;

import org.objectweb.ccm.filetransfer.*;

import javax.swing.*;

/**
 * This is the implementation of the OMG IDL3 filetransfer::TV component type.
 *
 * This class inherits from the local CCM_TV interface
 * generated by the OpenCCM's IDL3 to IDL2 mapping generator.
 *
 * This class also implements the filetransfer::Images event sink interface
 * to consume Images events.
 *
 * @author <a href="mailto:Areski.Flissi@lifl.fr">Areski Flissi</A>
 */

public class TVImpl
    extends org.objectweb.ccm.filetransfer.TVSessionComposition.ComponentImpl {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The name of the component. */
    private String name_;

    /** To refer to the GUI frame. */
    private javax.swing.JFrame frame_;
    FileTransfert_impl FileTransfertImpl = null;

    /** To refer to the GUI output area. */    
    private JButton screen;    
    static JButton label;
    

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public TVImpl() {

        // Instantiating the GUI.

        // Creates a Swing Frame.
        frame_ = new javax.swing.JFrame(name_ + "'s TV");
        frame_.setSize(215, 204);
        
        javax.swing.JPanel border = new javax.swing.JPanel(new java.awt.BorderLayout());
        
        screen = new JButton();   
        label = new JButton("...Waiting for signal....");
        
              
        // Packing the GUI
        border.add(screen, java.awt.BorderLayout.CENTER);
        border.add(label, java.awt.BorderLayout.SOUTH);
        frame_.getContentPane().add(border);

        // Display the GUI
        frame_.show();
        
        FileTransfertImpl =
                    new FileTransfert_impl(screen, label);
        
        
              

    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL Components::EnterpriseComponent
    //
    // ==================================================================

    /**
     * Complete the component configuration.
     *
     * @exception org.omg.Components.InvalidConfiguration
     *            Thrown if the configuration is invalid.     
     */
    public void configuration_complete()
        throws org.omg.Components.InvalidConfiguration {
        // Checks if the configuration is not completed.
        if (name_ == null)
            throw new org.omg.Components.InvalidConfiguration();

        
    }

    // ==================================================================
    //
    // Methods for the OMG IDL org.omg.Components.SessionComponent
    //
    // ==================================================================

    /**
     * Container callback to signal that the component is removed.
     *
     * @throw org.omg.Components.CCMException For any problems.
     */
    public void ccm_remove() throws org.omg.Components.CCMException {
        // Release the associated frame.
        frame_.dispose();
        frame_ = null;
    }

    // ==================================================================
    //
    // Methods for OMG IDL filetransfer::CCM_TV
    //
    // ==================================================================

    /**
     * The mutator method for the attribute name.
     *
     * @param n The name.
     */
    public void the_name(String n) {
        name_ = n;

        if (frame_ != null)
            frame_.setTitle(name_ + "'s TV");
    }

    /**
     * The accessor method for the attribute name.
     *
     * @return The name.
     */
    public String the_name() {
        return name_;
    }

    // ==================================================================
    //
    // Methods for the OMG IDL filetransfer::CCM_FilesReceiver interface.
    //
    // ==================================================================

    /**
     * Implementation of the OMG IDL filetransfer::FilesReceiver::push operation.
     *
     * @param event The received event.
     */
    public void push(Images event) {
	
	if (event.datafile != null) {
        // Display images
        //FileTransfertImpl.storeLastSend(event.datafile, event.filename);
        FileTransfertImpl.display_image(event.datafile, event.filename);
        
        System.out.println(event.filename + " received by TV component");
	}
        

    }

}
