/***************************************************************************/
/* COACH: Component Based Open Source Architecture for                     */
/*        Distributed Telecom Applications                                 */
/* See:   http://www.objectweb.org/                                        */
/*                                                                         */
/* Copyright (C) 2003 Lucent Technologies Nederland BV                     */
/*                    Bell Labs Advanced Technologies - EMEA               */
/*                                                                         */
/* Initial developer(s): Harold Batteram                                   */
/*                                                                         */
/* This library is free software; you can redistribute it and/or           */
/* modify it under the terms of the GNU Lesser General Public              */
/* License as published by the Free Software Foundation; either            */
/* version 2.1 of the License, or (at your option) any later version.      */
/*                                                                         */
/* This library is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        */
/* Lesser General Public License for more details.                         */
/*                                                                         */
/* You should have received a copy of the GNU Lesser General Public        */
/* License along with this library; if not, write to the Free Software     */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
/***************************************************************************/
package org.coach.actor.componentBrowser;

import javax.swing.tree.*;
import org.omg.CORBA.*;
import org.omg.Components.*;

class ComponentNode extends DefaultMutableTreeNode {
    protected static org.omg.CORBA.ORB orb;
    protected boolean explored = false;
    protected boolean leaf = true;
    protected String name = "";
    protected org.omg.CORBA.Object obj;
    

    public ComponentNode(String name) {
        this.name = name;
        setUserObject(this);
    }

    public ComponentNode(String name, org.omg.CORBA.Object obj) {
        this.name = name;
        this.obj = obj;
        leaf = false;
        setUserObject(this);
    }
    
    private ComponentNode(String name, org.omg.CORBA.Object obj, boolean leaf) {
        this.name = name;
        this.obj = obj;
        this.leaf = leaf;
        setUserObject(this);
    }
    
    public static void setOrb(org.omg.CORBA.ORB o) {
        orb = o;
    }

    public boolean getAllowsChildren() {
        return !leaf;
    }

    public boolean isLeaf() {
        return leaf;
    }

    public void explore() {
        explore(false);
    }

    public boolean isExplored() {
        return explored;
    }

    public String toString() {
        return name;
    }

    public String getIor() {
        String ior = "not an object!";
        org.omg.CORBA.Object obj = getObject();
        if (obj != null) {
            try {
                ior = orb.object_to_string(obj);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return ior;
    }

    public org.omg.CORBA.Object getObject() {
        if (obj != null) {
            return obj;
        }
        if (leaf) {
            try {
                ComponentNode p = (ComponentNode)getParent();
                CCMObject c = (CCMObject)p.getObject();
                obj = c.provide_facet(name);
                return obj;
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return null;
    }

    public boolean ping() {
        if (obj == null) {
            getObject();
        }
        if (obj != null) {
            try {
                obj._is_a("dummy");
            } catch (Exception e) {
                return false;
            }
            return true;
        }
        return false;
    }

    public void explore(boolean force) {
        if(!leaf && (!isExplored() || force)) {
            removeAllChildren();
            try {
                add(new ComponentNode(name, obj, true));
                FacetDescription[] facetDescription = ((CCMObject)obj).get_all_facets();
                for(int i = 0; i < facetDescription.length; i++) {
                    add(new ComponentNode(facetDescription[i].name));
                }

//                String[] opr = ((dsc.i_Component)obj).getFacets();
//                for(int i = 0; i < opr.length; i++) {
//                    add(new ComponentNode(opr[i]));
//                }

            } catch (Exception e) {
                e.printStackTrace();
            }

            explored = true;
        }
    }
}
