/***************************************************************************/
/* COACH: Component Based Open Source Architecture for                     */
/*        Distributed Telecom Applications                                 */
/* See:   http://www.objectweb.org/                                        */
/*                                                                         */
/* Copyright (C) 2003 Lucent Technologies Nederland BV                     */
/*                    Bell Labs Advanced Technologies - EMEA               */
/*                                                                         */
/* Initial developer(s): Harold Batteram                                   */
/*                                                                         */
/* This library is free software; you can redistribute it and/or           */
/* modify it under the terms of the GNU Lesser General Public              */
/* License as published by the Free Software Foundation; either            */
/* version 2.1 of the License, or (at your option) any later version.      */
/*                                                                         */
/* This library is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        */
/* Lesser General Public License for more details.                         */
/*                                                                         */
/* You should have received a copy of the GNU Lesser General Public        */
/* License along with this library; if not, write to the Free Software     */
/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
/***************************************************************************/
package org.coach.util;

final class ModestInputStream  {
    private byte bytes[];
    private int index;
    private boolean little_endian;
    public ModestInputStream(byte bytes[]) {
        this.bytes = bytes;
        little_endian = bytes[0] != 0;
        index = 1;
    }

    public boolean GetEndian() {
        return little_endian;
    }

    public byte ReadOctet() {
        return bytes[index++];
    }

    public short ReadUShort() {
        index += index % 2;

        if (little_endian) {
            return (short)(((bytes[index++]) & 0x00ff) | ((bytes[index++] << 8) & 0xff00));
        } else {
            return (short)(((bytes[index++] << 8) & 0xff00) | ((bytes[index++]) & 0x00ff));
        }
    }

    public int ReadULong() {
        int al = index % 4;

        if (al != 0) {
            index += 4 - al;
        }

        if (little_endian) {
            return ((bytes[index++]) & 0x000000ff) | ((bytes[index++] << 8) & 0x0000ff00) | ((bytes[index++] << 16) & 0x00ff0000) | ((bytes[index++] << 24) & 0xff000000);
        } else {
            return ((bytes[index++] << 24) & 0xff000000) | ((bytes[index++] << 16) & 0x00ff0000) | ((bytes[index++] << 8) & 0x0000ff00) | ((bytes[index++]) & 0x000000ff);
        }
    }

    public String ReadString() {
        int len = ReadULong() - 1;
        String str = new String(bytes, index, len);
        index += len;

        if (ReadOctet() != 0) {
            throw new org.omg.CORBA.INV_OBJREF("String should end with byte 0");
        }

        return str;
    }

    public byte[] ReadOctetArray() {
        int len = ReadULong();
        byte b[] = new byte[len];
        System.arraycopy(bytes, index, b, 0, len);
        index += len;
        return b;
    }
}
