/*====================================================================

created on 4 mars 2003

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2001-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Hameau Fabien.
Contributor(s): ______________________________________.

*/

package org.objectweb.ccm.Containers.MetaInformation;

import org.omg.Components.InvalidName;

/**
 * @author hameau
 */
public class ComponentInstanceImpl
extends InstanceImpl
implements ComponentInstance {
  
  private InterfaceInstance     _equivalent_interface;
  private InterfaceInstanceList _supported_interfaces;
  
  private AttributeInstanceList       _attributes;
  private FacetPortInstanceList       _facets;
  private ReceptaclePortInstanceList  _receptacles;
  private ConsumerPortInstanceList    _consumers;
  private EmitterPortInstanceList     _emitters;
  private PublisherPortInstanceList   _publishers;
  
  public ComponentInstanceImpl()
  {
    _attributes  = new AttributeInstanceListImpl();
    _facets      = new FacetPortInstanceListImpl();
    _receptacles = new ReceptaclePortInstanceListImpl();
    _consumers   = new ConsumerPortInstanceListImpl();
    _emitters    = new EmitterPortInstanceListImpl();
    _publishers  = new PublisherPortInstanceListImpl();
    
    _equivalent_interface = null;
    _supported_interfaces = new InterfaceInstanceListImpl();
  }


  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#equivalent_interface()
   */
  public InterfaceInstance equivalent_interface()
  {
    return _equivalent_interface;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#equivalent_interface(org.objectweb.ccm.Containers.MetaInformation.InterfaceInstance)
   */
  public void equivalent_interface(InterfaceInstance value)
  {
    _equivalent_interface = value;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#supported_interface()
   */
  public InterfaceInstanceList supported_interface()
  {
    return _supported_interfaces;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#supported_interface(org.objectweb.ccm.Containers.MetaInformation.InterfaceInstanceList)
   */
  public void supported_interface(InterfaceInstanceList value)
  {
    _supported_interfaces = value;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#attribute_instance_list()
   */
  public AttributeInstanceList attribute_instance_list()
  {
    return _attributes;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#attribute_instance_list(org.objectweb.ccm.Containers.MetaInformation.AttributeInstanceList)
   */
  public void attribute_instance_list(AttributeInstanceList value)
  {
    _attributes = value;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#facet_port_instance_list()
   */
  public FacetPortInstanceList facet_port_instance_list()
  {
    return _facets;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#facet_port_instance_list(org.objectweb.ccm.Containers.MetaInformation.FacetPortInstanceList)
   */
  public void facet_port_instance_list(FacetPortInstanceList value)
  {
    _facets = value;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#receptacle_port_instance_list()
   */
  public ReceptaclePortInstanceList receptacle_port_instance_list()
  {
    return _receptacles;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#receptacle_port_instance_list(org.objectweb.ccm.Containers.MetaInformation.ReceptaclePortInstanceList)
   */
  public void receptacle_port_instance_list(ReceptaclePortInstanceList value)
  {
    _receptacles = value;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#consumer_port_instance_list()
   */
  public ConsumerPortInstanceList consumer_port_instance_list()
  {
    return _consumers;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#consumer_port_instance_list(org.objectweb.ccm.Containers.MetaInformation.ConsumerPortInstanceList)
   */
  public void consumer_port_instance_list(ConsumerPortInstanceList value)
  {
    _consumers = value;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#emitter_port_instance_list()
   */
  public EmitterPortInstanceList emitter_port_instance_list()
  {
    return _emitters;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#emitter_port_instance_list(org.objectweb.ccm.Containers.MetaInformation.EmitterPortInstanceList)
   */
  public void emitter_port_instance_list(EmitterPortInstanceList value)
  {
    _emitters = value;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#publisher_port_instance_list()
   */
  public PublisherPortInstanceList publisher_port_instance_list()
  {
    return _publishers;
  }

  /* (non-Javadoc)
   * @see org.objectweb.ccm.Containers.MetaInformation.ComponentInstanceOperations#publisher_port_instance_list(org.objectweb.ccm.Containers.MetaInformation.PublisherPortInstanceList)
   */
  public void publisher_port_instance_list(PublisherPortInstanceList value)
  {
    _publishers = value;
  }

  ////////////////////////////////////////
  // adding info for recoding of CCMObject
  ////////////////////////////////////////
  
  // for facet
  
  public FacetPortInstance create_facet_port_instance(String name)
  {
    ComponentType _ctype = (ComponentType) this.type_reference();
    FacetPortType _fpt = null;
    try
    {
      _fpt = _ctype.facet_port_type_list().get_facet_port_type(name);
    }
    catch (InvalidName e)
    {
      System.err.println("Error : unbale to find facet '" +name+ "' for component");
      return null;
    }
    FacetPortInstance _fpi = new FacetPortInstanceImpl();
    _fpi.type_reference(_fpt);
    _fpi.related_instance_kind(instance_kind.COMPONENT_INSTANCE);
    _fpi.instance_reference(this);
    _fpi.object_ref(null);

    return _fpi;
  }
  
  // for receptacle
  
  public ReceptaclePortInstance create_receptacle_port_instance(String name)
  {
    ComponentType _ctype = (ComponentType) this.type_reference();
    ReceptaclePortType _rpt = null;
    try
    {
      _rpt = _ctype.receptacle_port_type_list().get_receptacle_port_type(name);
    }
    catch (InvalidName e)
    {
      System.err.println("Error : unbale to find receptacle '" +name+ "' for component");
      return null;
    }
    ReceptaclePortInstance _rpi = new ReceptaclePortInstanceImpl();
    _rpi.type_reference(_rpt);
    _rpi.related_instance_kind(instance_kind.COMPONENT_INSTANCE);
    _rpi.instance_reference(this);
    _rpi.object_ref(null);
   
    return _rpi;
  }

  // for consumer
  
  public ConsumerPortInstance create_consumer_port_instance(String name)
  {
    ComponentType _ctype = (ComponentType) this.type_reference();
    ConsumerPortType _cpt;
    try
    {
      _cpt = _ctype.consumer_port_type_list().get_consumer_port_type(name);
    }
    catch (InvalidName e)
    {
      System.err.println("Error : unbale to find consumer '" +name+ "' for component");
      return null;
    }
    ConsumerPortInstance _cpi = new ConsumerPortInstanceImpl();
    _cpi.type_reference(_cpt);
    _cpi.related_instance_kind(instance_kind.COMPONENT_INSTANCE);
    _cpi.instance_reference(this);
    _cpi.object_ref(null);

    
    return _cpi;
  }
  
  // for emitter
  
  public EmitterPortInstance create_emitter_port_instance(String name)
  {
    ComponentType _ctype = (ComponentType) this.type_reference();
    EmitterPortType _ept;
    try
    {
      _ept = _ctype.emitter_port_type_list().get_emitter_port_type(name);
    }
    catch (InvalidName e)
    {
      System.err.println("Error : unbale to find emitter '" +name+ "' for component");
      return null;
    }
    EmitterPortInstance _epi = new EmitterPortInstanceImpl();
    _epi.type_reference(_ept);
    _epi.related_instance_kind(instance_kind.COMPONENT_INSTANCE);
    _epi.instance_reference(this);
    _epi.object_ref(null);
   
    return _epi;
  }
  
  // for publisher
  
  public PublisherPortInstance create_publisher_port_instance(String name)
  {
    ComponentType _ctype = (ComponentType) this.type_reference();
    PublisherPortType _ppt;
    try
    {
      _ppt = _ctype.publisher_port_type_list().get_publisher_port_type(name);
    }
    catch (InvalidName e)
    {
      System.err.println("Error : unbale to find publisher '" +name+ "' for component");
      return null;
    }
    PublisherPortInstance _ppi = new PublisherPortInstanceImpl();
    _ppi.type_reference(_ppt);
    _ppi.related_instance_kind(instance_kind.COMPONENT_INSTANCE);
    _ppi.instance_reference(this);
    _ppi.object_ref(null);
   
    return _ppi;
  }
  
}
