/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2002 USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frederic
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.ccm.Deployment;

import org.omg.CosNaming.NameComponent;


public class AssemblyFactoryManagerServer  
       extends org.objectweb.ccm.CORBA.ApplicationServer
{
    
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    /*The factory name*/
    private String factoryName;
    /*The ior file path*/
    private String factoryIORFilePath;
    /*The NS registration name*/
    private NameComponent[]ncomp ;
    /**Reference on the current DCIManager*/
    private org.objectweb.openccm.OpenCCM_DCI.DCIManager DCI ;
    
     
    

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    private void
    computeArgs(String args[])
    {
        for(int i=0;i<args.length;i++){
            if(args[i].startsWith("FACTORYNAME="))
               this.factoryName=args[i].substring(12);
        }     
        factoryIORFilePath=System.getProperty("WorkDir")+"/"+factoryName+".IOR";      
    }    
    
   // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     **  The constructor.
     **/
    public
    AssemblyFactoryManagerServer()
    {
        // Set EntityResolver for CCM DTDs
        org.objectweb.ccm.descriptor.EntityResolver.setCCMResolver();
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
     **  The bootstrap main method.
     **
     **  @param args The command-line arguments.
     **/
    public static void
    main(String args[])
    {
        AssemblyFactoryManagerServer server = new AssemblyFactoryManagerServer();        
        /*ParameterConverter pc=new ParameterConverter();
        int status = server.start(pc.convertParameter(args));*/
        int status = server.start(args);
        System.exit(status);
    }

    // ==================================================================
    //
    // Methods for the org.objectweb.ccm.CORBA.ApplicationServer.
    //
    // ==================================================================

    /**
     **  Before running the CORBA::ORB.
     **
     **  @param args The command line arguments.
     **
     **  @return The status.
     **/
    public int
    before_run(String[] args)
    {
       
    try{
        
        computeArgs(args);
            
        //Initialize the ORB
        org.objectweb.ccm.Components.Runtime.init(org.objectweb.ccm.CORBA.TheORB.getORB());
        //Retrive the DCI reference
        DCI=
            org.objectweb.openccm.
            OpenCCM_DCI.DCIManagerHelper.
            narrow(org.objectweb.ccm.CORBA
                   .TheORB.resolve_initial_reference("DCIManager"));        
        
        //Retrieve a AssemblyFactoryManagerHome reference 
        org.objectweb.openccm.OpenCCM_DCI.AssemblyFactoryManagerHome AFMH=
            org.objectweb.openccm.OpenCCM_DCI.AssemblyFactoryManagerHomeHelper.
            narrow((new DeploymentComponentFactory()).
                   install_home
                   ("org.objectweb.openccm.OpenCCM_DCI.cif.AssemblyFactoryManagerHomeImpl.create_home"));
        
        //Create an AssemblyFactoryManager
        org.objectweb.openccm.OpenCCM_DCI.AssemblyFactoryManager AFM=
            AFMH.create();
        //Retrieve a AssemblyManagerHome reference         
        org.objectweb.openccm.OpenCCM_DCI.AssemblyManagerHome AMH=
            org.objectweb.openccm.OpenCCM_DCI.
            AssemblyManagerHomeHelper.narrow
            ((new DeploymentComponentFactory())
             .install_home("org.objectweb.openccm.OpenCCM_DCI.cif.AssemblyManagerHomeImpl.create_home"));
          
        //Connect the AssemblyManagerHome to the AssemblyFactoryManager component
        AFM.connect_assembly_manager_home(AMH);        
        // Plug the assemblyFactory interface needed for DCI::dci_deployment interface
        DCI.connect_assembly_factory(AFM.provide_assembly_factory());
        //Connect registration services 
        AFM.connect_home_registration(DCI.provide_home_registration());
        // Connect the home finder service
        AFM.connect_home_finder(DCI.provide_home_finder());
        // AFM.connect_trader_service(DCI.provide_trader_service());
        AFM.connect_dci_information(DCI.provide_dci_information());
        //Configure complete the Assembly Factory Manager
        AFM.configuration_complete();

        
         // Register the node if required
      //  if(registrationName!=null){
            org.omg.CosNaming.NamingContextExt nce=
                org.omg.CosNaming
                .NamingContextExtHelper
                .narrow(org.objectweb.ccm.CORBA.TheNameService
                        .getNamingContext().getNamingContext());
            
            String registrationName=
                System.getProperty("Assembly_factory_ns_dir")
                +factoryName;
                        
            ncomp=org.objectweb.ccm
                .descriptor.componentassembly.ccm
                .deployer.registrar.RegisterwithnamingDeployer
                .rebind(nce,registrationName,AFM);
       /*     org.objectweb.ccm
                .descriptor.componentassembly.ccm
                .RegisterwithnamingDeployer
                .rebind(nce,"AssemblyFactory",AFM.provide_assembly_factory());         
                */
         //   }            

        // Output the IOR of the DCIManager.
        org.objectweb.ccm.CORBA.TheORB.save_IOR(AFM, factoryIORFilePath);    
        
        
        return 0;
    }
    catch(Exception e){ 
        e.printStackTrace();
        System.out.println(e.getMessage());
        
    }
    return 0;

    }
    
    /**
     **  After running the CORBA::ORB.
     **/
    public void
    after_run()
    {
        try{
            if(DCI!=null)
               DCI.disconnect_assembly_factory();
               
            if(ncomp!=null){
                org.omg.CosNaming.NamingContextExt nce=
                    org.omg.CosNaming
                    .NamingContextExtHelper
                    .narrow(org.objectweb.ccm.CORBA.TheNameService
                            .getNamingContext().getNamingContext());
                
                nce.unbind(ncomp);
                
                System.err.println("The "+factoryName+" AssemblyFactory is unreferenced");
            }
        }
        catch(Exception e)
            {
                System.err.println("Cannot unbind The "+factoryName+"AssemblyFactory");
            }
    }   
    
}
