/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): Mathieu Vadet.

====================================================================*/

package org.objectweb.ccm.IR3;

import org.omg.CORBA.*;

/**
 * Implementation of the CORBA::UnionDef interface.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *         <a href="mailto:Mathieu.Vadet@lifl.fr">Mathieu Vadet</a>
 *
 * @version 0.5
 */

public class UnionDef_impl
     extends Container_impl
  implements UnionDefOperations
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The reference to the discriminator type object. */
    protected IDLType_ref discriminator_type_def_;

    /** The union members. */
    protected UnionMembers members_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** TODO */
    public
    UnionDef_impl(IFR ifr,
                  Container_impl container)
    {
        // Calls the Container_impl contructor.
        super(ifr, container);

        // Sets the tie servant object.
        setServant(new UnionDefPOATie(this));

        // Inits internal state.
        discriminator_type_def_ = new IDLType_ref(this);
        members_ = new UnionMembers(this);
    }

    // ==================================================================
    //
    // Internal methods inherited from IROject_impl.
    //
    // ==================================================================

    /**
     **  Warning : this operation must be implemented by subclasses.
     **  It allows us to avoid some casts while creating ::CORBA::TypeCode
     **/
    protected TypeCode
    recursiveType(org.objectweb.ccm.util.Vector idSeq)
    {
        int idx = idSeq.indexOf(id());
        if (idx!=-1)
            return getIFR().getTCF().create_recursive_tc(id());

        idSeq.add(id());
        UnionMember[] members = members_.getUnionMemberSeq(idSeq);
        idSeq.remove(id());

        // delegate to the TypeCodeFactory.
        return getIFR().getTCF().create_union_tc(id(), name(),
                                                 discriminator_type(),
                                                 members);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
        Obtain its CORBA::UnionDef object reference.
     **/
    public UnionDef
    asUnionDef()
    {
        return UnionDefHelper.narrow(asObject());
    }

    // ==================================================================
    //
    // For Container_impl class.
    //
    // ==================================================================

    /**
         Check if this kind of objects is accepted by the container.
     **/
    public boolean
    checkDefinitionKind(DefinitionKind dk)
    {
        // Only Structs, Unions and Enums are accepted!
        return (dk == DefinitionKind.dk_Struct)
            || (dk == DefinitionKind.dk_Union)
            || (dk == DefinitionKind.dk_Enum);
    }

    /**
        Check a new name according to already contained names.
     **/
    public void
    checkName(String name,
              boolean exclude_inherited,
              boolean in_inherited)
    {
        // call the Container_impl::checkName operation.
        super.checkName(name, exclude_inherited, in_inherited);

        // check if the name is a member name.
        members_.checkName(name);
    }

    // ==================================================================
    //
    // Internal methods for managing dependencies.
    //
    // ==================================================================

    /**
     * Cuts dependencies to other objects.
     */
    protected void
    cutDependencies()
    {
        // Cuts the dependency.
        discriminator_type_def_.cutDependency();

        // Cuts dependencies to union members types.
        members_.cutDependencies();

        // Calls the Container_impl::cutDependencies operation.
        super.cutDependencies();
    }

    // ==================================================================
    //
    // For CORBA::IRObject interface.
    //
    // ==================================================================

    /**
        IDL:omg.org/CORBA/IRObject/def_kind:1.0
     **/
    public DefinitionKind
    def_kind()
    {
        return DefinitionKind.dk_Union;
    }

    // ==================================================================
    //
    // For CORBA::IDLType interface.
    //
    // ==================================================================

    /**
        IDL:omg.org/CORBA/IDLType/type:1.0
     **/
    public TypeCode
    type()
    {
        // check for recursion.
        org.objectweb.ccm.util.Vector idSeq = new org.objectweb.ccm.util.Vector();
        return recursiveType(idSeq);
    }

    // ==================================================================
    //
    // For CORBA::Container interface.
    //
    // ==================================================================

    // ==================================================================
    //
    // For CORBA::UnionDef interface.
    //
    // ==================================================================

    /**
        IDL:omg.org/CORBA/UnionDef/discriminator_type:1.0
     **/
    public TypeCode
    discriminator_type()
    {
        // delegate to the IDLType reference.
        return discriminator_type_def_.recursiveType();
    }

    /**
        IDL:omg.org/CORBA/UnionDef/discriminator_type_def:1.0
     **/
    public IDLType
    discriminator_type_def()
    {
        // delegate to the IDLType reference.
        return discriminator_type_def_.asIDLType();
    }

    public void
    discriminator_type_def(IDLType val)
    {
        // for forward declarations
        if (val == null)
            discriminator_type_def_.setDependency(null);
        else
            // try to cast val to a local object
            // and delegate to the IDLType reference.
            discriminator_type_def_.setDependency( castToLocal(val) );
    }

    /**
        IDL:omg.org/CORBA/UnionDef/members:1.0
     **/
    public UnionMember[]
    members()
    {
        // delegate to the UnionMembers.
        return members_.getUnionMemberSeq();
    }

    public void
    members(UnionMember[] val)
    {
        // delegate to the UnionMembers.
        members_.setUnionMemberSeq(val);
    }
}
