/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.binder;

import org.objectweb.ccm.descriptor.componentassembly.beans.ConnecteventBean;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.ChildDeployerContext;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.util.FindbyDeployer;

/**
 * The connectevent deployer context defines all the connection requires for
 * connectevent establishment.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */

public class ConnecteventDeployerContext 
       extends ChildDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    private ConnecteventBean connectevent;
    private FindbyDeployer findbyDeployer;    
    private ConsumesportDeployer consumesportDeployer;
    private EmitsportDeployer emitsportDeployer;
    private PublishesportDeployer publishesportDeployer;
    private ExistinginterfaceDeployer existinginterfaceDeployer; 
    
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public Accessor methods.
    //
    // ==================================================================

    /**
     * @return
     */
    public ConnecteventBean 
    getConnectevent() 
    {
        return connectevent;
    }

    /**
     * @return
     */
    public ConsumesportDeployer 
    getConsumesportDeployer() 
    {
        return consumesportDeployer;
    }

    /**
     * @return
     */
    public EmitsportDeployer 
    getEmitsportDeployer() 
    {
        return emitsportDeployer;
    }

    /**
     * @return
     */
    public ExistinginterfaceDeployer 
    getExistinginterfaceDeployer() 
    {
        return existinginterfaceDeployer;
    }

    /**
     * @return
     */
    public FindbyDeployer 
    getFindbyDeployer() 
    {
        return findbyDeployer;
    }

    /**
     * @return
     */
    public PublishesportDeployer 
    getPublishesportDeployer() 
    {
        return publishesportDeployer;
    }

    /**
     * @param connectevent
     */
    public void 
    connectConnectevent(ConnecteventBean connectevent) 
    {
        this.connectevent = connectevent;
        connectDeployerDescription(connectevent);
    }

    /**
     * @param deployer
     */
    public void 
    connectConsumesportDeployer(ConsumesportDeployer deployer) 
    {
        consumesportDeployer = deployer;
    }

    /**
     * @param deployer
     */
    public void 
    connectEmitsportDeployer(EmitsportDeployer deployer) 
    {
        emitsportDeployer = deployer;
    }

    /**
     * @param deployer
     */
    public void 
    connectExistinginterfaceDeployer(ExistinginterfaceDeployer deployer) 
    {
        existinginterfaceDeployer = deployer;
    }

    /**
     * @param deployer
     */
    public void 
    connectFindbyDeployer(FindbyDeployer deployer) 
    {
        findbyDeployer = deployer;
    }

    /**
     * @param deployer
     */
    public void 
    connectPublishesportDeployer(PublishesportDeployer deployer) 
    {
        publishesportDeployer = deployer;
    }
    
    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */
    public void 
    initialize() 
    throws InitializationError 
    {
        if(getConnectevent()==null)
            getErrorManager()
           .submitException(new InitializationError(this,"Connection on connectevent bean is required "+
                                          "check the handler code it must specify this connection"));
        

        if(getPublishesportDeployer()==null&&getEmitsportDeployer()==null){ 
            getErrorManager()
           .submitException(new InitializationError(this,"One of publishesport/emitsport child must be specified in "+
                                                       "connectevent element check you connectevent element "+
                                                       "description.\n"+getStringifiedDeployerDescription()));   
        }
             
        if(getConsumesportDeployer()==null&&getExistinginterfaceDeployer()==null){    
            getErrorManager()
           .submitException(new InitializationError(this,"One of consumesport/existinginterface child must be specified in "+
                                                     "connectevent element check you connectevent element "+
                                                     "description.\n"+getStringifiedDeployerDescription()));
        }
           
        getLifeCycleManager().stepEndedSuccessFully();
    }
}
