/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.binder;

import org.objectweb.ccm.descriptor.componentassembly.Emitsport;
import org.objectweb.ccm.descriptor.componentassembly.beans.EmitsportBean;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.ChildDeployerContext;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.installer.ComponentinstantiationDeployer;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.util.FindbyDeployer;

/**
 * The emits port deployer context defines all the connection requires for
 * emitter resolution.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class EmitsportDeployerContext 
       extends ChildDeployerContext 
    {
 
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================   
    private EmitsportBean emitsport;
    private FindbyDeployer findbyDeployer;
    private ComponentinstantiationDeployer componentinstantiationDeployer;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public accessors methods.
    //
    // ==================================================================   
        
    /**
     * @return
     */
    public Emitsport 
    getEmitsport() 
    {
        return emitsport;
    }

    /**
     * @return
     */
    public FindbyDeployer 
    getFindbyDeployer() 
    {
        return findbyDeployer;
    }

    /**
     * @param emitsport
     */
    public void 
    connectEmitsport(EmitsportBean emitsport)
    {
        this.emitsport = emitsport;
        connectDeployerDescription(emitsport);
    }

    /**
     * @param deployer
     */
    public void 
    connectFindbyDeployer(FindbyDeployer deployer) 
    {
        findbyDeployer = deployer;
    }
    /**
     * @return
     */
    public ComponentinstantiationDeployer 
    getComponentinstantiationDeployer() 
    {
        return componentinstantiationDeployer;
    }

    /**
     * @param deployer
     */
    public void 
    connectComponentinstantiationDeployer(ComponentinstantiationDeployer deployer) 
    {
        componentinstantiationDeployer = deployer;
    }
    
    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */
    public void 
    initialize() 
    throws InitializationError
    {
          if(getEmitsport()==null)
            getErrorManager()
            .submitException(new InitializationError(this,"Connection on emitsport bean is required"+
                                                "check the handler code it must specify this connection"));
                                          
          if(getEmitsport().getComponentinstantiationref()!=null&&(
              getEmitsport().getComponentinstantiationref().getIdref()==null ||
              getEmitsport().getComponentinstantiationref().getIdref().length()==0)) 
                getErrorManager()
                .submitException(new InitializationError(this,"The idref attribute of the componentinstantiationref element"+
                                                         "must be fullfilled, check the emitsport element"+
                                                         "description\n."+getStringifiedDeployerDescription()));
          if(getEmitsport().getComponentinstantiationref()==null&&getFindbyDeployer()==null)
                getErrorManager()
                .submitException(new InitializationError(this,"One of componentinstantiationref/findby children must be"+
                                             "specified check the emitsport element"+
                                             "description\n."+getStringifiedDeployerDescription()));                                                              
        getLifeCycleManager().stepEndedSuccessFully();
      }


}
