/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.installer;

import java.util.LinkedList;
import org.objectweb.ccm.descriptor.componentassembly.Componentinstantiation;
import org.objectweb.ccm.descriptor.componentassembly.beans.ComponentinstantiationBean;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.*;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.registrar.*;
import org.omg.Components.CCMObject;
import org.omg.Components.Cookie;
import org.omg.Components.ExceededConnectionLimit;

/**
 * The componentinstantiation deployer context defines all the connection 
 * requires for the component instantiation/registration/configuration.
 * 
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class ComponentinstantiationDeployerContext
       extends ChildDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================  
    private ComponentinstantiationBean componentInstantiation;
    private ComponentinstantiationDeployInfo componentInstantiationDeployInfo;
    private ComponentpropertiesDeployer properties;
    private LinkedList registercomponentDeployers;
    private Cookie cookie;
    private CCMObject comp;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================    
    public ComponentinstantiationDeployerContext()
    {      
        registercomponentDeployers=new LinkedList();
    }
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public accessors methods.
    //
    // ==================================================================    
    public void 
    connectComponentinstantiation ( ComponentinstantiationBean componentInstantiation)
    {
        this.componentInstantiation=componentInstantiation;
        connectDeployerDescription(componentInstantiation);
    }
    
    public Componentinstantiation
    getComponentinstantiation()
    {
        return componentInstantiation;        
    }
    
    public void 
    connectComponentpropertiesDeployer(ComponentpropertiesDeployer properties)
    {
       this.properties=properties;
    }

    public ComponentpropertiesDeployer
    getComponentpropertiesDeployer()
    {
        return properties;
    }
    
    public void 
    connectRegistercomponentDeployer(RegistercomponentDeployer reg)
    {
        this.registercomponentDeployers.addLast(reg); 
    }

     public RegistercomponentDeployer[]
     getRegisterwithcomponentDeployers()
     {
         return (RegistercomponentDeployer[])
                 registercomponentDeployers.toArray
                 (new RegistercomponentDeployer[registercomponentDeployers.size()]);
     }
     /**
      * @return
      */
     public ComponentinstantiationDeployInfo getComponentInstantiationDeployInfo() {
         return componentInstantiationDeployInfo;
     }

     /**
      * @param info
      */
     public void connectComponentInstantiationDeployInfo(ComponentinstantiationDeployInfo info) {
         componentInstantiationDeployInfo = info;
     }
     
    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */
    public void initialize() throws InitializationError {
        if (getComponentinstantiation() == null)
            getErrorManager().submitException(
                new InitializationError(
                    this,
                    "Connection on componentinstantiation bean is required"
                        + "check the handler code it must specify this connection"));
        if (getComponentpropertiesDeployer() == null)
            getLogger().log(
                "No componentproperties specified for this componentinstantiation");

        getLifeCycleManager().stepEndedSuccessFully();
    }
 
    /**
     * This method provides the feature to register the component
     * on the appollon tree and connect it to the current assembly manager.
     * 
     * @param comp the component to register
     */    
    public void 
    storeComponentReference(CCMObject comp)
    {
      // storing the reference in the DeployInfo extension of the descriptor
      this.comp=comp;
      getComponentInstantiationDeployInfo().setCorbaReference(comp);
      getRootDeployerContext().connectComponent(comp);
      if(getRootDeployerContext().getAssemblyManager()!=null)
        try {
            cookie=getRootDeployerContext().getAssemblyManager().connect_components(comp);
        } catch (ExceededConnectionLimit e) {
            getLogger().log("Connection of component on AssemblyManager failed.");
        }
    }
    /**
     * This method provides the feature to unregister the component
     * on the appollon tree and disconnect it to the current assembly manager.
     * 
     */   
    public void 
    unstoreComponentReference()
    {
        getRootDeployerContext().disconnectComponent(comp);
        if(getRootDeployerContext().getAssemblyManager()!=null)
            try 
            {
                getRootDeployerContext()
                    .getAssemblyManager()
                    .disconnect_components(cookie);
            } 
            catch (ExceededConnectionLimit e) 
            {
                e.printStackTrace();
            }  
    }

}
