/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.installer;

//import the needed packages
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.*;
import org.omg.Components.CCMHome;

/**
 * ComponentplacementDeployer intiate components on an exiting home.
 * @author <a href="mailto:frederic.briclet@lifl.fr">Briclet Frederic</a>
 *
 * @version 0.1
 */
public class ComponentplacementDeployer
    extends ComponentplacementDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================     
    private CCMHome homePlaced;
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /**
    * Deploy is in charge to find the weeted home and instantiate
    * components.
    * 
    * @throws FatalDeploymentException if a fatal problem occured
    */
    public void deploy() 
    throws FatalDeploymentException 
    {
        try {
            homePlaced = getExistinghomeDeployer().resolveHome();
        } catch (ExistingHomeResolutionFailureException e) {
            getLifeCycleManager().stepAborded();
            getErrorManager().submitException(e);
            return;
        }
        traverse(this, getComponentinstantiationDeployer());
        getLifeCycleManager().stepEndedSuccessFully();
    }

    /**
    * Tear down the Componentplacement but does not remove the home
    * @throws FatalDeploymentException if a fatal problem occured
    */
    public void 
    tearDown() 
    throws FatalDeploymentException 
    {
        traverse(this, getComponentinstantiationDeployer());
        getLifeCycleManager().stepEndedSuccessFully();
    }
    
    /**
     * Componentplacement visitor used if failure state
     * 
     * @param comp The componentinstantiationdeployer to process
     * @param status the current deployer status
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    visit(ComponentinstantiationDeployer comp,
          DeployerFailureState status)
    throws FatalDeploymentException 
    {
        getLifeCycleManager().stepEndedSuccessFully();
    }
    /**
     * The componentinstantiation visitor used to instantiate component.
     * 
     * @param comp The componentinstantiationdeployer to process
     * @param status the current deployer status
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    visit(ComponentinstantiationDeployer comp,
          DeployerInactiveState status)
    throws FatalDeploymentException 
    {
        try {
            comp.deploy(homePlaced);
        } catch (ComponentInstantiationFailureException e) {
            getErrorManager().submitException(e);
        }

    }
    /**
     * The componentinstantiation visitor used to tear_down component
     * instante.
     * 
     * @param comp The componentinstantiationdeployer to process
     * @param status the current deployer status
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    visit(ComponentinstantiationDeployer comp,
          DeployerActiveState status)
    throws FatalDeploymentException 
    {
        comp.tearDown();
    }

}
  