/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.installer;

// Local Interface Import Statements
import org.objectweb.ccm.descriptor.componentassembly.beans.ComponentfilerefBeanImpl;
import org.objectweb.ccm.descriptor.componentassembly.beans.ComponentinstantiationBean;
import org.objectweb.ccm.descriptor.componentassembly.beans.HomeplacementBeanImpl;
import org.objectweb.ccm.descriptor.componentassembly.beans.RegisterwithhomefinderBeanImpl;
import org.objectweb.ccm.descriptor.componentassembly.beans.RegisterwithnamingBeanImpl;
import org.objectweb.ccm.descriptor.componentassembly.beans.RegisterwithtraderBeanImpl;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.HandlerBase;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.registrar.*;
import org.objectweb.ccm.descriptor.softpkg.ccm.DefaultDescriptorDeployer;
import org.objectweb.ccm.descriptor.softpkg.ccm.DescriptorDeployerInterface;

/**
 * This handler is used to produce homeplacementdeployer from an
 * homeplacement bean .
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class HomeplacementDeployerHandler 
       extends HandlerBase 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    private HomeplacementDeployer _deploy;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public methods.
    //
    // ================================================================== 
    /**
     * Produce the homeplacement deployer binded
     * to the givean @param homeplacement.
     * 
     * @param homeplacement The homeplacement bean 
     * @return the deployer produced in initialize state
     * @throws InitializationError thrown if a problem is detected
     */ 
    public Object 
    getInstance(HomeplacementBeanImpl homeplacement)
    throws InitializationError 
    {
        if(_deploy==null){
            _deploy=new HomeplacementDeployer();
            _deploy.connectHomeplacement(homeplacement);
            applyCommonConfig(_deploy);
            if(homeplacement.getComponentinstantiationList()!=null)          
            for(java.util.Iterator i=homeplacement.getComponentinstantiationList().iterator();i.hasNext(); ){
               ComponentinstantiationDeployer current=(ComponentinstantiationDeployer)
                                            getDeployer((ComponentinstantiationBean)i.next());
               _deploy.connectComponentInstantiationDeployer(current);            
            }        
            if(homeplacement.getRegisterwithnamingList()!=null)
                for(java.util.Iterator i=homeplacement.getRegisterwithnamingList().iterator();i.hasNext(); ){                                           ;
                  _deploy.connectRegisterwithnamingDeployer
                            ((RegisterwithnamingDeployer)
                            getDeployer((RegisterwithnamingBeanImpl)i.next()));            
               }
            if(homeplacement.getRegisterwithtraderList()!=null)
                for(java.util.Iterator i=homeplacement.getRegisterwithtraderList().iterator();i.hasNext(); ){                                           ;
                  _deploy.connectRegisterwithtraderDeployer
                            ((RegisterwithtraderDeployer)
                            getDeployer((RegisterwithtraderBeanImpl)i.next()));            
               }    
            _deploy.connectHomeplacementInfo   
                  ( (HomeplacementDeployInfo)
                          homeplacement.getExtensionManager().
                          getExtensionByName("ccm.deployer.installer.DeployInfo")
                          .getInstance() );

            if(homeplacement.getDestination()!=null)
                _deploy.connectDestinationDeployer
                ((DestinationDeployer)getDeployer(homeplacement.getDestination()));
   
            ComponentfileDeployer componentfile;
            
            if(homeplacement.getComponentfileref()==null)
                 throw new InitializationError(_deploy,"No componentfileref was specified "+
                                   "check you homeplacement element description it must specify it\n"+
                                   _deploy.getStringifiedDeployerDescription() 
                                     );                 
            if(homeplacement.getComponentimplref()==null)
                 throw new InitializationError(_deploy,"No componentimplref was specified "+
                                   "check you homeplacement element description it must specify it\n"+
                                   _deploy.getStringifiedDeployerDescription() 
                                     );                             
            
            try{     
                if(((ComponentfilerefBeanImpl)
                                homeplacement
                                .getComponentfileref())
                                .pullIdref()==null)
                throw new InitializationError
                            (_deploy,"The componentfileref "+homeplacement
                                .getComponentfileref().getIdref()+" is not a valid componentfile "+
                                "identifiant, check your CAD file it specifies bad componentfile"+
                                " idref\n"+_deploy.getStringifiedDeployerDescription());
                
                if(((ComponentfilerefBeanImpl)
                              homeplacement
                              .getComponentfileref())
                              .pullIdref()==null)
                 throw new InitializationError(_deploy,"Bad componentfile identifiant was specified "+
                           homeplacement.getComponentfileref().getIdref()+
                           " denote a non existing componentfile check you homeplacement element description\n"+
                           _deploy.getStringifiedDeployerDescription() 
                             );                                               
                              
                componentfile=(ComponentfileDeployer)
                                getDeployer(((ComponentfilerefBeanImpl)
                                              homeplacement
                                              .getComponentfileref())
                                              .pullIdref());
            } 
           catch(java.lang.ClassCastException e){                   
                 throw new InitializationError(_deploy,"Similar identifiants was detected, it was expected that "+
                                               homeplacement.getComponentfileref().getIdref()+
                                               " denote a componentfile but a "+
                                                ((ComponentfilerefBeanImpl)
                                                homeplacement.getComponentfileref())
                                                .pullIdref().getClass().getName()+" was found "+
                                                "check your CAD file a identifiant is used for two different elements;"+
                                                " To achieved successfully the deployment use different name for this two identifiants"); 
            }   
            catch(java.lang.NullPointerException e){
                 throw new InitializationError(_deploy,"Bad componentfileref was specified "+
                                               homeplacement.getComponentfileref().getIdref()+
                                               " denote a non existing componentfile check you homeplacement element description\n"+
                                               _deploy.getStringifiedDeployerDescription() 
                                                 );                 
            }
                            
            _deploy.connectSoftpkgDeployer(componentfile.getSoftpkgDeployer());
           
                       
            if(componentfile.getImplementationDeployer
                (homeplacement.getComponentimplref().getIdref())!=null){                                
            
                _deploy.connectImplementationDeployer
                    (componentfile.getImplementationDeployer
                    (homeplacement.getComponentimplref().getIdref()));
              
                }
            else {
                 throw new InitializationError(_deploy,"Bad componentimplref  was specified "+
                               homeplacement.getComponentimplref().getIdref()+
                               " denote a non existing implementation check you homeplacement element description\n"+
                               _deploy.getStringifiedDeployerDescription() 
                                 );                                 
            }
            if(_deploy.getDestinationDeployer()!=null)
            { 
                ((DestinationDeployerContext)
                _deploy.getDestinationDeployer())
                        .connectSoftpkgDeployer(_deploy.getSoftpkgDeployer());
            
                ((DestinationDeployerContext)
                  _deploy.getDestinationDeployer())
                         .connectImplementationDeployer
                         (_deploy.getImplementationDeployer());
                  
            }
            DescriptorDeployerInterface descr=new DefaultDescriptorDeployer();
            if(_deploy.getSoftpkgDeployer().getDescriptorDeployers()!=null&&
               _deploy.getSoftpkgDeployer().getDescriptorDeployers().length>0){

                   descr=_deploy.getSoftpkgDeployer().getDescriptorDeployers()[0];

               }

            if(_deploy.getImplementationDeployer().getDescriptorDeployers()!=null&&
               _deploy.getImplementationDeployer().getDescriptorDeployers().length>0){

                   descr=_deploy.getImplementationDeployer().getDescriptorDeployers()[0];

               }

            if(homeplacement.getRegisterwithhomefinderList()!=null)
               for(java.util.Iterator i=homeplacement.getRegisterwithhomefinderList().iterator();i.hasNext(); ){               
                   RegisterwithhomefinderDeployer rwhf=                
                           ((RegisterwithhomefinderDeployer)
                           getDeployer((RegisterwithhomefinderBeanImpl)i.next()));
                    rwhf.connectDescriptorDeployer(descr);
                   _deploy.connectRegisterwithhomefinderDeployer(rwhf);        
              }
            // The homplacementis initialize by it parents.  
            //_deploy.initialize();      
        }      
  
        return (_deploy);
    }

}
