/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.registrar;

import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.DeployerActiveState;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.DeployerInactiveState;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.FatalDeploymentException;
import org.omg.CORBA.Object;
import org.omg.Components.CCMObject;

/**
 * CLASS_DESCRIPTION.
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class RegistercomponentDeployer
       extends RegistercomponentDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    private Object to_register;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================
    /**
     * makecomponentRegistration execute the component registration
     * @param component The component to register
     * @throws FatalDeploymentException if a fatal problem occured
     */    
    public void 
    makeComponentRegistration(CCMObject component)
    throws FatalDeploymentException {       
       to_register=component;
       
       try{
           if(getRegistercomponent().getProvidesidentifier()!=null)
                       to_register=component.provide_facet(getRegistercomponent()
                                                           .getProvidesidentifier().getValue());
            else if(getRegistercomponent().getConsumesidentifier()!=null)
                       to_register=component.get_consumer(getRegistercomponent()
                                                          .getConsumesidentifier().getValue());
       }
       catch(Exception e){
            //getErrorManager().submitException(e);
            //TODO dfinir l'erreur approprie.
       }
                                                                 
       traverse(this,getRegisterwithnamingDeployers());
       traverse(this,getRegisterwithtraderDeployers());
       getLifeCycleManager().stepEndedSuccessFully();
    }
    /**
     * Unregister the component reference.
     * 
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    undoComponentRegistration()
    throws FatalDeploymentException 
    {                                    
       traverse(this,getRegisterwithnamingDeployers());
       traverse(this,getRegisterwithtraderDeployers());
       getLifeCycleManager().stepEndedSuccessFully();
    }
    /**
     * RegisterwithnamingDeployer visitor used to make the registration
     * @param deployer The registration deployer to execute
     * @param status The Registercomponent current status
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    visit(RegisterwithnamingDeployer deployer,DeployerInactiveState status)
    throws FatalDeploymentException
    {
        try{
            deployer.rebind(to_register);
        }
        catch(NameserviceRegistrationFailureException e){
            getErrorManager().submitException(e);
        }

    }
    /**
     * RegisterwithnamingDeployer visitor used to make the unregistration
     * @param deployer The registration deployer to execute
     * @param status The Registercomponent current status
     * @throws FatalDeploymentException if a fatal problem occured
     */
    public void 
    visit(RegisterwithnamingDeployer deployer,DeployerActiveState status)
    throws FatalDeploymentException
    {
        try{
            deployer.unbind();
        }
        catch(NameserviceRegistrationFailureException e){
            getErrorManager().submitException(e);
        }

    }
    /**
     * RegisterwithtraderDeployer visitor used to make the registration
     * @param deployer The registration deployer to execute
     * @param status The Registercomponent current status
     * @throws FatalDeploymentException if a fatal problem occured
     */    
    public void 
    visit(RegisterwithtraderDeployer deployer,DeployerInactiveState status)
    throws FatalDeploymentException
    {
        try{
            deployer.deploy(to_register);
        }
        catch(Exception e){
            //getErrorManager().submitException(e);
        }
    }
    /**
     * RegisterwithtraderDeployer visitor used to make the registration
     * @param deployer The registration deployer to execute
     * @param status The Registercomponent current status
     * @throws FatalDeploymentException if a fatal problem occured
     */    
    public void 
    visit(RegisterwithtraderDeployer deployer,DeployerActiveState status)
    throws FatalDeploymentException
    {
       try{
           deployer.tearDown();
       }
       catch(Exception e){
          // getErrorManager().submitException(e);
       }
    }
    
}
