/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.registrar;

import java.util.LinkedList;

import org.objectweb.ccm.descriptor.componentassembly.beans.RegistercomponentBean;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.ChildDeployerContext;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.InitializationError;

/**
 * The registercomponent deployer context defines all the connection requires for
 * component registration. 
 *
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class RegistercomponentDeployerContext 
       extends ChildDeployerContext 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================    
    private RegistercomponentBean registercomponent;   
    private LinkedList registerwithnamingDeployers;
    private LinkedList registerwithtraderDeployers;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    public RegistercomponentDeployerContext(){
        registerwithnamingDeployers=new LinkedList();
        registerwithtraderDeployers=new LinkedList();
    }
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public accessors methods.
    //
    // ==================================================================    
    /**
     * @return
     */
    public RegistercomponentBean 
    getRegistercomponent() 
    {
        return registercomponent;
    }

    /**
     * @param bean
     */
    public void 
    connectRegistercomponent(RegistercomponentBean bean) 
    {
        registercomponent = bean;
    }

    public void 
    connectRegisterwithnamingDeployer(RegisterwithnamingDeployer reg) 
    {
        this.registerwithnamingDeployers.addLast(reg);
    }

    public RegisterwithnamingDeployer[] 
    getRegisterwithnamingDeployers() 
    {
        return (
            RegisterwithnamingDeployer[]) registerwithnamingDeployers.toArray(
            new RegisterwithnamingDeployer[registerwithnamingDeployers.size()]);
    }

    public void 
    connectRegistertraderDeployer(RegisterwithtraderDeployer reg) 
    {
        this.registerwithtraderDeployers.addLast(reg);
    }

    public RegisterwithtraderDeployer[] 
    getRegisterwithtraderDeployers() 
    {
        return (
            RegisterwithtraderDeployer[]) registerwithtraderDeployers.toArray(
            new RegisterwithtraderDeployer[registerwithtraderDeployers.size()]);
    }   
    /**
     * This initialization method is used to check that all the services and 
     * information required to deploy are presents. If all is OK the deployer 
     * is put in inactive deployer state waiting for the deployment processing.
     * 
     * @exception InitializationError is thrown if a problem is detected 
     */
    public void initialize() throws InitializationError {
        // TODO Auto-generated method stub
        if(getRegistercomponent()==null)
           getErrorManager()
           .submitException(new InitializationError(this,"Connection on registercomponent bean is required"+
                                                   "check the handler code it must specify this connection"));
        getLifeCycleManager().stepEndedSuccessFully();
    }


    

}
