/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Briclet Frdric.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.root;

// Local Interface Import Statements
import java.net.ServerSocket;
import org.ist.coach.DCI.AssemblyManager;
import org.ist.coach.DCI.DCIInformation;
import org.objectweb.ccm.descriptor.ZipEntryRetriever;
import org.objectweb.ccm.descriptor.componentassembly.beans.ComponentassemblyBeanImpl;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.base.*;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.binder.*;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.installer.*;
import org.objectweb.ccm.descriptor.componentassembly.ccm.deployer.managers.*;
import org.omg.Components.HomeFinder;
import org.omg.Components.HomeRegistration;
import org.omg.CosNaming.NamingContextExt;

/**
 * The ComponentasemblydeployerHandler in charge to instantiate the component
 * assemblyDeployer and setup all the connections required.
 * 
 * @author <a href="mailto:briclet@lifl.fr">Briclet Frdric</a>
 *
 * @version 0.1
 */
public class ComponentassemblyDeployerHandler 
       extends HandlerBase 
    {
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================
    private ComponentassemblyDeployer _deploy;           
    private NamingContextExt namingcontext;
    private HomeFinder homefinder;
    private HomeRegistration homeregistration;
    private DCIInformation dciinfo;
    private ZipEntryRetriever zipEntryRetriever;
    private ServerSocket serverSocket;
    private AssemblyManager assemblyManager;
    private DeploymentLogger deploymentLogger;
    private ErrorManager errorManager;
    private DestinationDeployerFactory destinationDeployerFactory;
    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================      
    /**
     * Produce the componentassemblydeployer deployer binded
     * to the givean @param cai.
     * 
     * @param cai The componentassembly bean 
     * @return the deployer produced in initialize state
     * @throws InitializationError thrown if a problem is detected
     */ 
    public Object 
    getInstance(ComponentassemblyBeanImpl cai)
    throws InitializationError 
    {
        if(_deploy==null){
            getDeploymentLogger().log("<<STEP1>> Begin the deployers instantiation/initialization");
            _deploy=new ComponentassemblyDeployer();            
            _deploy.connectComponentassembly(cai);
            DefaultLifeCycleManager dlcm=new DefaultLifeCycleManager();
            _deploy.connectLifeCycleManager(dlcm);
            dlcm.connectLogger(getDeploymentLogger());  
            dlcm.connectManagedDeployer(_deploy);                                 
            _deploy.connectDCIInformation(getDciinfo());
            _deploy.connectNamingContextExt(getNamingcontext());
            _deploy.connectHomeFinder(getHomefinder());
            _deploy.connectHomeregistration(getHomeregistration());
            _deploy.connectServerSocket(getServerSocket());
            _deploy.connectZipEntryRetriever(getZipEntryRetriever());
            _deploy.getZipEntryRetriever().connectStreamManager(_deploy);
            _deploy.connectDeploymentLogger(getDeploymentLogger());           
            _deploy.connectErrorManager(getErrorManager());
            _deploy.connectDestinationDeployerFactory(getDestinationDeployerFactory());
            //dem.connectObservedDeployer(_deploy);
                    
            this.connectRootDeployerContext(_deploy);
            
            if(cai.getComponentfiles()!=null){
                ComponentfilesDeployer c=
                          (ComponentfilesDeployer)getDeployer(cai.getComponentfiles());
                 
                 //TODO: Change the affectation of the root context         
                _deploy.connectComponentfilesDeployer(c);   
            }     
            
            //according to the DTD partitioning cannot be empty or null
            PartitioningDeployer p=(PartitioningDeployer)
                                    getDeployer(cai.getPartitioning());
                                   
           _deploy.connectPartitioningDeployer(p);              
                                     
            if(cai.getConnections()!=null){
                _deploy.connectConnectionsDeployer
                    ((ConnectionsDeployer)getDeployer(cai.getConnections()));  
            }    
           
            _deploy.initialize(); 
            getDeploymentLogger().log("<</STEP1>>Deployers initialization ended");                     
        }  
        return (_deploy);
    }    
    
    /**
     * @param manager
     */
    public void 
    connectAssemblyManager(AssemblyManager manager) 
    {
        assemblyManager = manager;
    }

    /**
     * @param information
     */
    public void 
    connectDciinfo(DCIInformation information) 
    {
        dciinfo = information;
    }

    /**
     * @param finder
     */
    public void 
    connectHomefinder(HomeFinder finder) 
    {
        homefinder = finder;
    }

    /**
     * @param registration
     */
    public void 
    connectHomeregistration(HomeRegistration registration) 
    {
        homeregistration = registration;
    }

    /**
     * @param ext
     */
    public void 
    connectNamingcontext(NamingContextExt ext) 
    {
        namingcontext = ext;
    }

    /**
     * @param socket
     */
    public void 
    connectServerSocket(ServerSocket socket) 
    {
        serverSocket = socket;
    }

    /**
     * @param retriever
     */
    public void 
    connectZipEntryRetriever(ZipEntryRetriever retriever) 
    {
        zipEntryRetriever = retriever;
    }

    /**
     * @return
     */
    private AssemblyManager 
    getAssemblyManager() 
    {
        return assemblyManager;
    }

    /**
     * @return
     */
    private DCIInformation 
    getDciinfo() 
    {
        return dciinfo;
    }

    /**
     * @return
     */
    private HomeFinder 
    getHomefinder() 
    {
        return homefinder;
    }

    /**
     * @return
     */
    private HomeRegistration 
    getHomeregistration() 
    {
        return homeregistration;
    }

    /**
     * @return
     */
    private NamingContextExt 
    getNamingcontext() 
    {
        return namingcontext;
    }

    /**
     * @return
     */
    private ServerSocket 
    getServerSocket() 
    {
        return serverSocket;
    }

    /**
     * @return
     */
    private ZipEntryRetriever 
    getZipEntryRetriever() 
    {
        return zipEntryRetriever;
    }

    /**
     * @return
     */
    public DeploymentLogger 
    getDeploymentLogger() 
    {
        return deploymentLogger;
    }

    /**
     * @param logger
     */
    public void 
    connectDeploymentLogger(DeploymentLogger logger) 
    {
        deploymentLogger = logger;
    }

    /**
     * @return
     */
    public DestinationDeployerFactory 
    getDestinationDeployerFactory() 
    {
        return destinationDeployerFactory;
    }

    /**
     * @return
     */
    public ErrorManager 
    getErrorManager() 
    {
        return errorManager;
    }

    /**
     * @param factory
     */
    public void 
    connectDestinationDeployerFactory(DestinationDeployerFactory factory) 
    {
        destinationDeployerFactory = factory;
    }

    /**
     * @param manager
     */
    public void connectErrorManager(ErrorManager manager) {
        errorManager = manager;
    }

}
