/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey, Philippe Merle.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.command.api;

// Package dependencies
import org.objectweb.corba.ast.api.FileScope;

/**
 * Interface of the cidl_cif command.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *         <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 1.1
 */

public interface CIDLtoCIF
         extends Compiler,
                 Generator
{
    /**
     * Obtains CIF skeletons output directory.
     *
     * @result The CIF skeletons output directory.
     */
    public String
    getCIFOutputDirectory();

    /**
     * Obtains CIDL dependencies output directory.
     *
     * @result The output directory.
     */
    public String
    getDependenciesOutputDirectory();

    /**
     * Obtains unwanted prefixs for CIDL dependencies.
     *
     * @result The list of prefixs.
     */
    public String[]
    getNoPrefix();

    /**
     * Generates CIF interfaces and skeletons
     * from an AST FileScope instance.
     *
     * Note that checkComponentRepository() and initAST() methods
     * must be called before.
     *
     * @param filescope The source AST FileScope returned by the compile() method.
     * @param inputfile - The source file.
     * @param outputfile - The file name for the IDL mapping.
     * @param base_dir - The base directory for java mapping.
     * @param userIncludes - User files to include "...".
     *
     * @return True if ok, else false.
     */
    public boolean
    generate_cif(FileScope filescope,
                 String inputfile,
                 String outputfile,
                 String base_dir,
                 String[] userIncludes);

    /**
     * Generates CIF dependencies from an AST FileScope instance.
     *
     * Note that checkComponentRepository() and initAST() methods
     * must be called before.
     *
     * @param filescope - The source AST FileScope returned by the compile() method.
     * @param base_dir - The base directory for dependencies output.
     * @param unwanted_prefixs - Unwanted prefixs for CIDL dependencies.
     *
     * @return True if ok, else false.
     */
    public boolean
    generate_cif_dependencies(FileScope filescope,
                              String base_dir,
                              String[] unwanted_prefixs);
}
