/*====================================================================

created on 9 juil. 2003
OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2001-2002 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Hameau Fabien.
Contributor(s): ______________________________________.

*/
package org.objectweb.corba.command.lib;

import org.objectweb.corba.generator.metainformation.lib.IDL_JavaMIGenerator;
import org.objectweb.util.cmdline.lib.DefaultCommandLine;
import org.objectweb.util.cmdline.lib.DefaultOptionArgument;

/**
 * Implementation of the IDLtoMI command 
 * 
 * @author <a href="mailto:hameau@lifl.fr">Hameau Fabien</a> 
 * 
 */
//implements org.objectweb.corba.command.api.IDLtoMI

public class IDLtoMI
extends GeneratorBase
{

  
  // ==================================================================
     //
     // Constructor.
     //
     // ==================================================================

     /** The default constructor. */
  public
  IDLtoMI()
     {
         // Calls the CompilerGeneratorBase constructor.
       super(new DefaultCommandLine(
        "idl_to_mi",
        "declaration",
        new String[] {
        "Compile an OMG IDL3 file and generate its associated:",
        "- local MI type implementations"
        },
        true),
        "none");
  
         // Specify output base directory
     
       odir_ = new DefaultOptionArgument(
                       new String[] { "-d" },
                       "outputdir",
                       new String[] {
                         "Generate Java implementations into directory <outputdir>,",
                         "default is generated/"
                       },
                       "generated" );
       getCommandLine().addOption(odir_);
  }
  // ==================================================================
  //
  // Internal state.
  //
  // ==================================================================

  /** Include Options. */
  private OptionMultipleArguments userInclude_;
  /** Output directory Option. */
  org.objectweb.util.cmdline.api.OptionArgument odir_; // -d <directory>

  /**
   * run 
   * 
   * @param commandLine
   * 
   */
   
  public int run(String[] args)
  {
    String filename = args[0];

       // Inits the OpenCCM's Abstract Syntax Tree.
       
       if(!initAST())
           return -1;

       if (!generateMI(args[0],getOutputDirectory()))
           return -1;

       // All is OK.
       return 0;
  }
  
  public String getOutputDirectory()
  {
    return odir_.getArgument();
  }
  //==================================================================
  //
  // Public methods for org.objectweb.corba.command.api.IDLtoMI
  //
  // ==================================================================
  
  /**
   * Generates MI interfaces from an AST FileScope instance.
   *
   * Note that checkComponentRepository() and initAST() methods
   * must be called before.
   *
   * @param filescope The source AST scope of the declaration.
   * @param base_dir - The base directory for java mapping.
   *
   * @return True if ok, else false.
   */
  
  public 
  boolean 
  generateMI(String decl,
             String base_dir)
  {
    // Switch the OpenCCM Interface Repository in mode OMG IDL 3.0
    getComponentRepository().as_IDL3_repository();

    // Retrieves the scope to generate.
    org.objectweb.corba.ast.api.Scope scope = null;
    try
    {
        scope = (org.objectweb.corba.ast.api.Scope)getAST().lookup(decl);
    }
    catch(ClassCastException e)
    {
        getConsole().error(decl + "is not a scope!");
        return false;
    }

    if(scope == null)
    {
        getConsole().error("Declaration " + decl + " not found!");
        return false;
    }

    getConsole().message("Generating MetaInformation implementations for " + decl + "...");

    // Launchs the generator.
   
    IDL_JavaMIGenerator MI_gen = new IDL_JavaMIGenerator(getAST());

    // Generates.
    try
    {
      MI_gen.idl_to_java(base_dir,scope);
    }
    catch(org.objectweb.corba.generator.common.lib.GenerationException ex)
    {
        report_exception(ex);
        return false;
    }

   
    getConsole().message(" ...");
    // generate the MI typ eimplementation for the given AST
    
    return true;
  }
  
  // ==================================================================
  //
  // Static public methods.
  //
  // ==================================================================

  /**
   * The main bootstrap method.
   *
   * @param args The command line arguments.
   */
  public static void
  main(String[] args)
   { 
      IDLtoMI idl2mi = new IDLtoMI();
      idl2mi.runMain(args);
  }
   
  
  
  
  
  
  
  
  
  
}