/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): 

====================================================================*/

package org.objectweb.corba.command.lib;

// Package dependencies.
import org.objectweb.util.cmdline.api.OptionArgument;
import org.objectweb.util.cmdline.api.OptionFlag;

import org.objectweb.util.cmdline.lib.DefaultCommandLine;
import org.objectweb.util.cmdline.lib.DefaultOptionArgument;
import org.objectweb.util.cmdline.lib.DefaultOptionFlag;

import org.objectweb.ccm.CORBA.TheORB;

import org.objectweb.ccm.IR3.IFR;

import org.omg.CORBA.ComponentIR.Repository;

/**
 * Implementation of the ir3_start command.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 *
 * @version 0.1
 */

public class IR3Server
     extends ApplicationServerBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The command line option for the file to store the IOR. */
    private OptionArgument option_IOR_file_;

    /** The command line option for disabling OMG IDL 2.x mappings. */
    private OptionFlag option_disable_mapping_;

    /** Reference to the OMG IDL compiler. */
    private IR3Feed compiler_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /** The default constructor. */
    public
    IR3Server()
    {
        // Calls the ApplicationServerBase constructor.
        super(new DefaultCommandLine("ir3server",
                                     "[omg_idl_files]",
                                     "Start the OpenCCM Interface Repository",
                                     true));

        // Specify the command line option for the file to store the IOR.
        option_IOR_file_ = new DefaultOptionArgument(
                                   "--ior-file",
                                   "ior_file",
                                   new String [] {
                                       "Set the file to store the OpenCCM Interface Repository IOR,",
                                       "default is ./InterfaceRepository.IOR"
                                   },
                                   "./InterfaceRepository.IOR" );
        getCommandLine().addOption(option_IOR_file_);

        // Specify the command line option for disabling OMG IDL 2.x mappings.
        option_disable_mapping_ = new DefaultOptionFlag(
                                          "--no-mappings",
                                          "Disable OMG IDL 2.x mappings",
                                          false);
        getCommandLine().addOption(option_disable_mapping_);

        // Create the OMG IDL 3.0 compiler.
        compiler_ = new IR3Feed(getCommandLine());
        compiler_.setConsole(getConsole());
        compiler_.getPreprocessorApplication().setConsole(getConsole());
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.util.cmdline.api.Application
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.command.api.Application
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for org.objectweb.corba.command.api.ApplicationServer
    //
    // ==================================================================

    /**
     * Before running the CORBA::ORB object.
     *
     * Must be defined in subclasses.
     *
     * @param args The command line arguments.
     *
     * @return The status.
     */
    public int
    before_run(String[] args)
    {
        // Create an OMG IDL3 repository.
        IFR repositoryServer = new IFR(!option_disable_mapping_.getFlag());
        Repository repositoryRef = repositoryServer.getRepository().asComponentRepository();

        // Set the initial CORBA reference of the InterfaceRepository.
        TheORB.register_initial_reference("InterfaceRepository", repositoryRef);

        // Compiles the OMG IDL 3.0 files.
        int result = compiler_.run(args);
        if(result != 0)
            return result;

        System.out.println("The OpenCCM OMG IDL3 Repository is ready.");

        // Output the IOR of the IR3.
        TheORB.save_IOR(repositoryRef, option_IOR_file_.getArgument());

	return 0;
    }

    /**
     * After running the CORBA::ORB object.
     *
     * Must be defined in subclasses.
     */
    public void
    after_run()
    {
    }

    // ==================================================================
    //
    // Static public methods.
    //
    // ==================================================================

    /**
     * The main bootstrap method.
     *
     * @param args The command line arguments.
     */
    public static void
    main(String[] args)
    {
        IR3Server ir3server = new IR3Server();
        ir3server.runMain(args);
    }
}
