/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.generator.cif.lib;

// Package dependencies.
import org.objectweb.corba.generator.java.lib.*;
import org.objectweb.corba.generator.java.ast.api.*;
import org.objectweb.corba.generator.java.ast.lib.*;
import org.objectweb.corba.generator.common.lib.GenerationException;
import org.objectweb.corba.ast.api.*;

/**
 * This class generates CIF implementation templates files.
 * Firstly, a java ast is fed, then classes are generated by the JavaGenerator.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class CIF_JavaImplGenerator
     extends org.objectweb.corba.generator.common.lib.GeneratorBase
  implements org.objectweb.corba.generator.cif.api.CIF_JavaImplGenerator
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The java repository */
    private Repository repository_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * @param ast - The Abstract Syntax Tree.
     **/
    public CIF_JavaImplGenerator(org.objectweb.corba.ast.api.AST ast)
    {
        super(ast);

        // Init internal state
        repository_ = new RepositoryImpl();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.generator.cif.api.CIF_JavaImplGenerator.
    //
    // ==================================================================

    /**
     * Generate java files for the CIF.
     *
     * @param base_dir - The base directory where files will be generated.
     * @param scope - The scope to map.
     *
     * @exception GenerationException - Thrown if a problem occurs during generation.
     **/
    public void
    cif_to_java_impl(String base_dir, Scope scope)
    throws GenerationException
    {
        java.io.File out_dir = null;
        repository_ = new RepositoryImpl();
        java.util.Vector vect = null;
        ValueDecl[] value_array = null;
        CompositionDecl[] compositions = null;

        // Check and create the output directory
        try{
            out_dir = org.objectweb.corba.generator.common.lib.FileManager.mkdir(base_dir);
        }catch(GenerationException ex){
            System.err.println(ex.getMessage());
            return;
        }

        /** Get all Value Types and Events contained in the file scope **/
        vect = getAllDeclarations(scope, DeclarationKind.dk_event +
                                         DeclarationKind.dk_value);
        value_array = (ValueDecl[])vect.toArray(new ValueDecl[0]);
        for (int i=0; i<value_array.length; i++)
        {
            org.objectweb.corba.generator.cif.api.ValueTypeImplMapping value
                = new ValueTypeImplMapping(value_array[i]);
            value.toJavaValueTemplate(repository_);
            value.toJavaValueFactoryTemplate(repository_);
        }

        /** Get all compositions contained in the file scope **/
        vect = getAllDeclarations(scope, DeclarationKind.dk_composition);
        compositions = (CompositionDecl[])vect.toArray(new CompositionDecl[0]);

        // For each composition, call mapping
        for (int i=0; i<compositions.length; i++)
        {
            // Generate the home implementation template
            org.objectweb.corba.generator.cif.api.HomeImplMapping home_mapping
                = new HomeImplMapping(compositions[i]);
            home_mapping.toJavaHomeTemplate(repository_);

            // Generate the component implementation template
            org.objectweb.corba.generator.cif.api.ComponentImplMapping comp_mapping
                = new ComponentImplMapping(compositions[i]);
            comp_mapping.toJavaComponentTemplate(repository_);

            // Generate segments implementation templates
            org.objectweb.corba.generator.cif.api.SegmentImplMapping seg_mapping
                = new SegmentImplMapping(compositions[i]);
            seg_mapping.toJavaSegmentTemplates(repository_);
        }

        // Generate Java Files
        org.objectweb.corba.generator.java.lib.JavaGenerator java_gen = new JavaGenerator();
        java.util.Vector v = new java.util.Vector();
        v.add("cif_jimpl.vm");
        java_gen.initialize("CIF_JIMPL", v);
        java_gen.generate(repository_, base_dir);
    }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

}
