/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.corba.generator.cif_idl.lib;

// Package dependencies.
import org.objectweb.corba.ast.utils.api.CompositionInfo;
import org.objectweb.corba.ast.api.CompositionDecl;
import org.objectweb.corba.ast.api.ModuleDecl;
import org.objectweb.corba.ast.api.Declaration;
import org.objectweb.corba.generator.cif_idl.api.ProxyHomeMapping;
import org.objectweb.corba.generator.cif_idl.api.HomeExecutorMapping;

/**
 * This class generates CIF IDL for an OMG CIDL Composition.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class CompositionMapping
  implements org.objectweb.corba.generator.cif_idl.api.CompositionMapping
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The composition to map. */
    private CompositionInfo comp_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * @param composition - The composition to map.
     */
    public CompositionMapping(CompositionDecl composition)
    {
        // Init internal states
        comp_ = new org.objectweb.corba.ast.utils.lib.CompositionInfo(composition);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================


    // ==================================================================
    //
    //  Public methods for org.objectweb.corba.generator.cif_idl.api.CompositionMapping.
    //
    // ==================================================================

    /**
     * Declare CIF interfaces into Interface Repository.
     *
     * @return The new created CIF Module.
     */
    public ModuleDecl
    declareCIF()
    {
        ModuleDecl parent, module;
        Declaration[] decls = null;
        ProxyHomeMapping ph_mapping = null;
        HomeExecutorMapping he_mapping = null;

        // Get the composition parent module
        parent = (org.objectweb.corba.ast.api.ModuleDecl)
                    comp_.getComposition().getParent();

        // Declare the CIF Module
        module = parent.declareModule( comp_.getComposition().getName() );
        module.create();

        // Call mapping for home executor
        he_mapping = new org.objectweb.corba.generator.cif_idl.lib.HomeExecutorMapping( comp_.getHomeExecutor() );
        he_mapping.declareCIF(module, comp_);

        // Call mapping for proxy home
        if (comp_.getProxyHome() != null)
        {
            ph_mapping = new org.objectweb.corba.generator.cif_idl.lib.ProxyHomeMapping( comp_.getProxyHome() );
            ph_mapping.declareCIF( module,
                                   comp_,
                                   he_mapping.getCIFMapping() );
        }

        return module;
    }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

}
