/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/

package org.objectweb.openccm.browser.Components;

/** The Browser's imports */
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.util.browser.api.Table;
import org.objectweb.util.browser.core.naming.DefaultName;
import org.objectweb.util.browser.core.naming.DefaultEntry;
import org.objectweb.openccm.browser.CORBA.ConsoleFactory;

/** The Java API's imports */
import java.util.List;
import java.util.Vector;
import java.util.Iterator;

/** The CCM's imports */
import org.omg.Components.CCMObject;
import org.omg.Components.ComponentPortDescription;
import org.omg.Components.FacetDescription;
import org.omg.Components.ReceptacleDescription;
import org.omg.Components.ConsumerDescription;
import org.omg.Components.EmitterDescription;
import org.omg.Components.PublisherDescription;
import org.omg.Components.PortDescription;

import org.objectweb.openccm.browser.CORBA.TypageCORBA;
import org.objectweb.openccm.browser.util.ior.IorPrinter;

/**
 * Displays ports of the given <code>CCMObject</code> component.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class ProvidedInterfacesTable
    implements Table {

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================
    
    //==================================================================
    //
    // No constructor.
    //
    //==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected String getName(org.omg.CORBA.Object o) {
        TypageCORBA tc = new TypageCORBA(o, org.objectweb.ccm.CORBA.TheORB.getORB());
        return tc.getTypeID();
    }

    //==================================================================
    //
    // Public methods for Table interface.
    //
    //==================================================================

    /**
     * Overriding methods
     * @see org.objectweb.util.browser.api.Table#getHeaders()
     */
    public String[] getHeaders(TreeView treeView) {
        return new String[]{"Port","Interface"};
    }
    
    /**
     * Overriding methods
     * @see org.objectweb.util.browser.api.Table#getRows(org.objectweb.util.browser.api.TreeView)
     */
    public Object[][] getRows(TreeView treeView) {
        org.omg.CORBA.ORB orb = org.objectweb.ccm.CORBA.TheORB.getORB();
        IorPrinter iorPrinter = null;
        List l = new Vector();

        CCMObject component = (CCMObject) treeView.getSelectedObject();
        ComponentPortDescription cpd = component.get_all_ports();

        FacetDescription[] fd = cpd.facets;
        for (int i = 0; i < fd.length; i++)
            l.add(new Object[]{
                new DefaultEntry(fd[i], new DefaultName(fd[i].name)),
                    new DefaultEntry(fd[i].facet_ref, new DefaultName(getName(fd[i].facet_ref)))
                    });

        ConsumerDescription[] cd = cpd.consumers;
        for (int i = 0; i < cd.length; i++)
            l.add(new Object[]{
                new DefaultEntry(cd[i], new DefaultName(cd[i].name)),
                    new DefaultEntry(cd[i].consumer, new DefaultName(getName(cd[i].consumer)))
                    });
                  
        Object[][] contenu = new Object[l.size()][3];
        Iterator it = l.iterator();
        int cpt = 0;
        while(it.hasNext()){
            contenu[cpt] = (Object[])it.next();
            cpt++;
        }

        return contenu;
 
   }
}
