/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.browser.Components;

import org.omg.Components.CCMObject;
import org.omg.Components.PublisherDescription;
import org.omg.Components.SubscriberDescription;

/**
 * This class is composed by
 * <ul>
 * <li>A SubscriberDescription reference.</li>
 * <li>The associated PublisherDescription reference.</li>
 * <li>The component reference associates to the PublisherDescription</li>
 * </ul>
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class SubscriberContainer {

    /** The SubscriberDescription reference. */
    protected SubscriberDescription subscriber_;

    /** The associated PublisherContainer */
    protected PublisherContainer publisherContainer_;

    /**
     * @return
     */
    public SubscriberDescription getSubscriber() {
        return subscriber_;
    }

    /**
     * @param description
     */
    public void setSubscriber_(SubscriberDescription subscriber) {
        subscriber_ = subscriber;
    }

    /**
     * @param container
     */
    public void setPublisherContainer_(PublisherContainer publisherContainer) {
        publisherContainer_ = publisherContainer;
    }

    /**
     * @return
     */
    public PublisherDescription getPublisher() {
        if (publisherContainer_ != null)
            return publisherContainer_.getPublisher();
        return null;
    }

    /**
     * @return
     */
    public CCMObject getComponent() {
        if (publisherContainer_ != null)
            return publisherContainer_.getComponent();
        return null;
    }

}
