/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.browser.Components;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.GridLayout;

import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;

import org.objectweb.util.browser.api.MenuItemTreeView;
import org.objectweb.util.browser.api.MenuItem;
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.core.common.DynamicTree;
import org.objectweb.util.browser.core.api.ExtendedEntry;

import org.objectweb.openccm.browser.menu.TreeDialogSingleton;

import org.omg.Components.CCMObject;
import org.omg.Components.ConsumerDescription;
import org.omg.Components.PublisherDescription;

/**
 * This items allows to subscribe a consumer to a publisher 
 * (<code>::Components::CCMObject::subscribe</code> called).
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class SubscribesAction 
    implements MenuItem {

    public int getStatus(TreeView arg0){
        return MenuItem.ENABLED_STATUS;
    }

    public void actionPerformed(MenuItemTreeView e) throws Exception {
        
        PublisherContainer pc = (PublisherContainer) e.getSelectedObject();
        PublisherDescription publisher = pc.getPublisher();
        CCMObject component = pc.getComponent();

        DynamicTree tree = TreeDialogSingleton.getInstance();

        JPanel treePanel = new JPanel();
        treePanel.setLayout(new GridLayout(1, 0));
        treePanel.setPreferredSize(new Dimension(450, 350));
        treePanel.add(new JScrollPane(tree));
        int result =
            JOptionPane.showOptionDialog((Component) e.getActionEvent().getSource(), treePanel, "Select a consumer", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, null);
        if (result == 0) {
            Entry entry = tree.getSelectedEntry();
            if (entry != null) {
                Object object = ((ExtendedEntry)entry).getWrappedObject();;
                if (object != null) {
                    try{
                        ConsumerDescription consumer = (ConsumerDescription)object;
                        if (component != null && publisher != null && consumer != null) {
                            component.subscribe(publisher.name, consumer.consumer);
                        }
                    } catch (ClassCastException e1) {
                        throw new Exception("ConsumerDescription expected !");
                    }
                }
            }
        }
    }

}
