/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.browser.CosNaming;

/** The administration console's API imports */
import org.objectweb.util.browser.api.MenuItem;
import org.objectweb.util.browser.api.MenuItemTreeView;
import org.objectweb.util.browser.api.TreeView;
import org.objectweb.openccm.browser.menu.OpenCCMBrowserConstants;
import org.objectweb.openccm.browser.menu.JFileChooserSingleton;
import org.objectweb.openccm.browser.menu.TreeDialogSingleton;
import org.objectweb.util.browser.gui.api.DialogAction;
import org.objectweb.util.browser.gui.api.DialogBox;
import org.objectweb.util.browser.gui.lib.DefaultDialogBox;
import org.objectweb.util.browser.gui.lib.LabelBox;
import org.objectweb.util.browser.gui.lib.FileChooserBox;
import org.objectweb.util.browser.gui.lib.TreeBox;

/** The java API's imports */
import javax.swing.JOptionPane;
import java.awt.Component;
import java.awt.Dimension;
import java.io.File;
import java.io.BufferedReader;
import java.io.FileReader;

/** The CORBA's imports */
import org.omg.CORBA.ORB;
import org.omg.CosNaming.NamingContextExt;

/**
 * This action binds an object into the NameService.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class BindObject 
  implements MenuItem, DialogAction 
{

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    /** The dialog box */
    protected DialogBox dialog_;
    
    /** The associated NamingContext */
    protected NamingContextExt namingContext_ = null;

    /** The name of the object */
    protected LabelBox name_ = null;

    /** The IOR file to use to bind the object */
    protected FileChooserBox iorFile_ = null;

    /** The tree used to select the object to bind */
    protected TreeBox tree_ = null;

    //==================================================================
    //
    // No constructor.
    //
    //==================================================================

    //==================================================================
    //
    // Internal methods.
    //
    //==================================================================
    
    /**
     * Binds the object into the current NameService
     */
    protected void bind(NamingContextExt naming, String id, org.omg.CORBA.Object o) {
        try {
            naming.rebind(naming.to_name(id), o);
        } catch (org.omg.CosNaming.NamingContextPackage.NotFound e) {
            System.out.println(getClass().getName() + " : Object Not Found Exception !");
        } catch (org.omg.CosNaming.NamingContextPackage.CannotProceed e) {
            System.out.println(getClass().getName() + " : CannotProceed Exception");
        } catch (org.omg.CosNaming.NamingContextPackage.InvalidName e) {
            System.out.println(getClass().getName() + " : InvalidName Exception");
        }
    }

    /**
     * Creates a box containing all the box to specify all the params
     */
    protected void createBox() {
        name_ = new LabelBox("Object's name");
        dialog_.addElementBox(name_);
        iorFile_ = new FileChooserBox("IOR file",JFileChooserSingleton.getInstance(OpenCCMBrowserConstants.IOR_FILE_CHOOSER),false);        
        dialog_.addElementBox(iorFile_);
        tree_ = new TreeBox(TreeDialogSingleton.getInstance(),false);  
        tree_.setPreferredSize(new Dimension(350, 150));
        dialog_.addElementBox(tree_);
    }

    //==================================================================
    //
    // Public methods for MenuItem interface.
    //
    //==================================================================

    /**
     * @see org.objectweb.util.browser.api.MenuItem#getStatus(org.objectweb.util.browser.api.TreeView)
     */
    public int getStatus(TreeView treeView) {
        return MenuItem.ENABLED_STATUS;
    }

    /**
     * The action to execute
     */
    public void actionPerformed(MenuItemTreeView e) {
        namingContext_ = (NamingContextExt) e.getSelectedObject();
        dialog_ = new DefaultDialogBox("Binds an object into the NameService");      
        createBox();
        dialog_.setValidateAction(this);
        dialog_.show();
    }

    //==================================================================
    //
    // Public methods for DialogAction interface.
    //
    //==================================================================

    /**
     * Executes an action
     */
    public void executeAction() throws Exception {
        File file = iorFile_.getFile();
        Object selectedObject = tree_.getObject();
        org.omg.CORBA.Object object = null;
        if (file != null) {
            String ior = null;
            try {
                BufferedReader in = new BufferedReader(new FileReader(file));
                ior = in.readLine();
            } catch (java.io.FileNotFoundException err) {
                System.out.println(file + " : File not found !");
            } catch (java.io.IOException err) {
                System.out.println(file + " : Error while reading !");
            }
            if (ior != null && ior.startsWith("IOR:")) {
                ORB orb = org.objectweb.ccm.CORBA.TheORB.getORB();
                object = orb.string_to_object(ior);
            }
        } else if (selectedObject != null) {
            try {
                object = (org.omg.CORBA.Object) selectedObject;
            } catch (ClassCastException e1) {
                throw new Exception("You must select a org.omg.CORBA.Object \n Found : " + selectedObject.getClass().getName());
            }
        }
        if (object != null)
            bind(namingContext_, name_.getLabel(), object);
        else
            throw new Exception("The valid object to bind is expected !");
    }
}
