/*===========================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Sylvain Leblanc.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.CosTrading;

/** The administration console's API imports */
import org.objectweb.util.browser.api.Context;
import org.objectweb.util.browser.api.Wrapper;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.core.naming.DefaultName;
import org.objectweb.util.browser.core.naming.DefaultEntry;

/** The OMG Trading Service imports. */
import org.omg.CosTrading.Lookup;
import org.omg.CosTradingRepos.ServiceTypeRepository;
import org.omg.CosTradingRepos.ServiceTypeRepositoryHelper;


/**
 * Basic implementation of the Context interface
 * for managing org.omg.CosTrading.Lookup references. 
 *
 * @author <a href="mailto:Sylvain.Leblanc@lifl.fr">Sylvain Leblanc</a>
 * @version 0.1
 */
public class LookupContext 
  implements Context, Wrapper
{

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The CosTrading main interface, i.e. org.omg.CosTrading.Lookup. */
    private Lookup lookup_;

    /** 
     * States if the Trading Service must be manipulated by an admin
     * or a user. Default value is the user view.
     */
    private static boolean admin_view_=false;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    /** 
     * Toogles the view of the trading service. If the previous view
     * was an admin. view, it becomes a user view and vice-versa. <br/>
     *
     * <b>Warning:</b> toogling the view will impact all Lookup
     * references in the administration console.
     */
    public static void toogleAdminUserView() 
    {
        LookupContext.admin_view_ = ! LookupContext.admin_view_;
    }

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

    public Entry[] getEntries() {
        org.omg.CORBA.Object object = lookup_.type_repos();
        ServiceTypeRepository str = ServiceTypeRepositoryHelper.narrow(object);
        Entry[] values = null;
        
        // The admin view consider all CosTrading management interfaces.
        if (LookupContext.admin_view_) {
            values = new Entry[6];
            values[0] = new DefaultEntry(str, new DefaultName("Service Type Repository"), this);
            values[1] = new DefaultEntry(new Queries(lookup_), new DefaultName("Queries"), this);
            values[2] = new DefaultEntry(new Offers(lookup_.admin_if()), 
                                         new DefaultName("Registered Offers"), this);
            values[3] = new DefaultEntry(new ProxyOffers(lookup_.admin_if()), 
                                         new DefaultName("Proxy Offers"), this);
            values[4] = new DefaultEntry(lookup_.admin_if(), new DefaultName("Trader Config"), this);
            values[5] = new DefaultEntry(lookup_.link_if(), new DefaultName("Trader Links"), this);
        // The user view only consider CosTrading query an service type repos. interfaces.
        } else {
            values = new Entry[2];
            values[0] = new DefaultEntry(str, new DefaultName("Service Type Repository"), this);
            values[1] = new DefaultEntry(new Queries(lookup_), new DefaultName("Queries"), this);
        }
        return values;
    }

    // ==================================================================
    //
    // Additional public methods for Wrapper interface.
    //
    // ==================================================================

    /**
     * Fix the wrapped object
     *
     * @param object The object to wrap
     *
     */
    public void setWrapped(Object object) {
        lookup_ = (Lookup) object;
    }

    /**
     * Gets the wrapped object
     *
     * @return The wrapped object
     *
     */
    public Object getWrapped() {
        return lookup_;
    }

}
