/*===========================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s):Sylvain Leblanc.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.openccm.browser.CosTrading.gui;

/** The Java API's imports */
import java.awt.Color;
import javax.swing.BoxLayout;
import javax.swing.Box;
import javax.swing.border.TitledBorder;
import javax.swing.JLabel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.TableModel;

/** OMG Trading Service imports. */
import org.omg.CosTrading.RegisterPackage.OfferInfo;

/**
 * Panel used to view content of
 * org.omg.CosTrading.RegisterPackage.OfferInfo instances. Objects of
 * this type are obtained by the <code>list_offer</code> method of the
 * <code>org.omg.CosTrading.Admin</code> interface.
 *
 * @author <a href="mailto:Sylvain.Leblanc@lifl.fr">Sylvain Leblanc</a>
 * @version 0.1
 */
public class OfferInfoPanel extends DefaultNodeViewPanel {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The OfferInfo to view. */
    protected OfferInfo offerInfo_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default constructor.
     */
    public OfferInfoPanel() {
        setBackground(Color.white);
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for class DefaultNodeViewPanel.
    //
    // ==================================================================

    /**
     * Creates the content of the panel.
     */
    public void onSetTreeView() {
        if (getTreeView() != null) {
            offerInfo_ = (OfferInfo)getTreeView().getSelectedObject();
            if (offerInfo_ != null) {
                
                javax.swing.JPanel pane = new javax.swing.JPanel();
                pane.setBackground(Color.white);
                pane.setBorder(new TitledBorder(null, " " + offerInfo_.type + " ",TitledBorder.CENTER,TitledBorder.TOP));

                // Creates a JTable for properties
                TableModel dataModel = new OfferPropsTableModel(offerInfo_.properties);
                JTable table = new JTable(dataModel);
                table.setBackground(Color.white);
                
                // Adding a scroll pane to the JTable
                JScrollPane scroll = new JScrollPane(table);
                scroll.setBackground(Color.white);
                scroll.getViewport().setBackground(Color.white);
               
                // Adding the label and the scroll pane in the Panel
                Box box = Box.createVerticalBox();
                box.add(scroll);

                pane.add(box);

                add(pane);
            }
        }
    }
}














