/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.browser.DCI;

/** The consoles's imports */
import org.objectweb.openccm.browser.CORBA.TypageCORBA;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.api.Context;
import org.objectweb.util.browser.api.Wrapper;
import org.objectweb.util.browser.core.naming.DefaultEntry;
import org.objectweb.util.browser.core.naming.DefaultName;

import org.ist.coach.DCI.NodeManager;
import org.omg.Components.Deployment.ServerActivator;
import org.ist.coach.DCI.ExtComponentInstallation;

/**
 * This context displays the <code>ServerActivator</code> and the <code>ComponentInstallation</code> registered in the given NodeManager.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class NodeManagerContext 
    implements Context, Wrapper {

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    /** The NodeManager to browse. */
    protected NodeManager nodeManager_ = null;

    // ==================================================================
    //
    // No constructor.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    protected String getName(org.omg.CORBA.Object o) {
        TypageCORBA tc = new TypageCORBA(o, org.objectweb.ccm.CORBA.TheORB.getORB());
        return tc.getTypeID();
    }

    // ==================================================================
    //
    // Public methods for interface Context.
    //
    // ==================================================================

    public Entry[] getEntries() {
        java.util.List v = new java.util.Vector();

        // Adding the ServerActivator
        ServerActivator serverActivator = nodeManager_.provide_server_activator();
        if(serverActivator!=null)
            v.add(new DefaultEntry(serverActivator, new DefaultName("Component Servers")));
    
        // Adding the ComponentInstallation
        ExtComponentInstallation componentInstallation = nodeManager_.provide_component_installation();
        if(componentInstallation!=null)
            v.add(new DefaultEntry(componentInstallation, new DefaultName("Installed Components")));
        
        // Return the array of entry
        return (Entry[]) v.toArray(new Entry[0]);
    }

    // ==================================================================
    //
    // Additional public methods for Wrapper interface.
    //
    // ==================================================================

    /**
     * Fix the wrapped object
     * @param object The object to wrap
     */
    public void setWrapped(Object object) {
        nodeManager_ = (NodeManager) object;
    }

    /**
     * Gets the wrapped object
     * @return The wrapped object
     */
    public Object getWrapped() {
        return nodeManager_;
    }

}
