/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

====================================================================*/
package org.objectweb.openccm.browser.Deployment;

/** The console's imports. */
import org.objectweb.openccm.browser.CORBA.TypageCORBA;
import org.objectweb.util.browser.api.Context;
import org.objectweb.util.browser.api.Wrapper;
import org.objectweb.util.browser.api.Entry;
import org.objectweb.util.browser.core.naming.DefaultName;
import org.objectweb.util.browser.core.naming.DefaultEntry;

/** The CCM's imports */
import org.omg.Components.Deployment.Container;
import org.omg.Components.CCMHome;

/**
 * Basic implementation of the Context interface
 * for managing Container object.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 *
 * @version 0.1
 */
public class ContainerContext
    implements Context, Wrapper {

	// ==================================================================
	//
	// Internal state.
	//
	// ==================================================================

	/** The container. */
	private Container container_ = null;

	// ==================================================================
	//
	// No Constructors.
	//
	// ==================================================================

	// ==================================================================
	//
	// Internal methods.
	//
	// ==================================================================

	/**
	 * Return the name of the Entry
	 */
	protected String getName(org.omg.CORBA.Object o) {
		TypageCORBA tc = new TypageCORBA(o, org.objectweb.ccm.CORBA.TheORB.getORB());
		return tc.getTypeID();
	}

	/**
	 * Obtains the associated ComponentServer.
	 *
	 * @return The associated ComponentServer.
	 */
	protected Container getContainer() {
		return container_;
	}

	// ==================================================================
	//
	// Public methods for interface Context.
	//
	// ==================================================================

	public Entry[] getEntries() {
		CCMHome[] objects = getContainer().get_homes();
		Entry[] values = new Entry[objects.length];
		for (int i = 0; i < objects.length; i++)
			values[i] = new DefaultEntry(objects[i], new DefaultName(getName(objects[i]) + " (" + i + ")"), this);
		return values;
	}

	// ==================================================================
	//
	// Additional public methods for Wrapper interface.
	//
	// ==================================================================

	/**
	 * Fix the wrapped object
	 * @param object The object to wrap
	 */
	public void setWrapped(Object object) {
		container_ = (Container) object;
	}

	/**
	 * Gets the wrapped object
	 * @return The wrapped object
	 */
	public Object getWrapped() {
		return container_;
	}

}
