/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): Alex Andrushchak.

====================================================================*/

package org.objectweb.openccm.services.pss.jdo.lib;

// Package dependencies
import org.objectweb.openccm.services.pss.common.lib.PIDHelper;


/**
 *  This is a base class for Storage Homes implemented with JDO.
 */
public abstract class StorageHomeBase
              extends org.objectweb.openccm.services.pss.common.lib.StorageHomeBase
           implements org.objectweb.openccm.services.pss.jdo.api.StorageHomeBase
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    public StorageHomeBase()
    {
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.omg.CosPersistentState.StorageHomeBase
    //
    // ==================================================================

    /**
     * Retrieve a storage object with its short pid.
     *
     * @param short_pid - The short pid to find.
     *
     * @throws org.omg.CosPersistentState.NotFound ifstorage object can't be found.
     *
     * @return The binding storage object.
     */
    public java.lang.Object
    find_by_short_pid(byte[] short_pid)
    throws org.omg.CosPersistentState.NotFound
    {
        // First, search in storage type incarnations
        java.util.Iterator it = _storage_type_incarnations.iterator();
        org.omg.CosPersistentState.StorageObject so = null;

        while(it.hasNext())
        {
            so = (org.omg.CosPersistentState.StorageObject) it.next();
            if ( java.util.Arrays.equals(so.get_short_pid(), short_pid) )
            {
                return so;
            }
        }

        // If not found, search in the database
        java.lang.Object oid = null,
                         obj = null;
        javax.jdo.PersistenceManager pm = null;
        org.objectweb.openccm.services.pss.common.api.CatalogBase catalog = null;
        java.lang.Class clazz = null;

        pm = ((org.objectweb.openccm.services.pss.jdo.api.CatalogBase) get_catalog()).
                get_persistence_manager();

        catalog = (org.objectweb.openccm.services.pss.common.api.CatalogBase) get_catalog();
        clazz = catalog.get_connector().get_storage_object_factory( get_st_rid() );

        oid = pm.newObjectIdInstance
                (
                    clazz,
                    new String(short_pid)
                );
        try
        {
            obj = pm.getObjectById(oid, true);
            ((org.objectweb.openccm.services.pss.common.api.StorageObject) obj).initialize(this);
            // add obj to _storage_type_incarnations
            _storage_type_incarnations.add(obj);
        }catch(javax.jdo.JDODataStoreException ex){
            throw new org.omg.CosPersistentState.NotFound();
        }
        return obj;
    }

    // ==================================================================
    //
    // Methods for org.objectweb.openccm.services.pss.common.api.StorageHomeBase
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.objectweb.openccm.services.pss.jdo.api.StorageHomeBase
    //
    // ==================================================================

    /**
     * Create a pid for a storage type.
     *
     * @param short_pid - The short_pid of the storage type to encode.
     *
     * @return The storage type PID.
     */
    public byte[]
    create_pid(String short_pid)
    {
        return PIDHelper.encode(get_rid(), short_pid);
    }

    /**
     * Must be called before create method invokation.
     */
    public void
    before_create()
    {
        ((org.objectweb.openccm.services.pss.jdo.api.CatalogBase) get_catalog()).begin_tx();
    }

    /**
     * Must be called after create method invokation.
     *
     * @param st - The storage type to make persistent.
     */
    public void
    after_create(org.objectweb.openccm.services.pss.jdo.api.StorageObject st)
    {
        org.objectweb.openccm.services.pss.jdo.api.CatalogBase catalog = null;
        javax.jdo.PersistenceManager pm = null;

        st.initialize(this);

        // Commit the storage Type
        catalog = (org.objectweb.openccm.services.pss.jdo.api.CatalogBase) get_catalog();
        pm = catalog.get_persistence_manager();
        pm.makePersistent(st);

        catalog.commit_tx();
    }

    /**
     * Must be called after create method invokation.
     *
     * @param fields_names - Name of fields contained in the key.
     * @param fields_types - Type of fields contained in the key.
     * @param key_values - Value of fields contained in the key.
     *
     * @return The storage object matching to key values.
     *
     * @throws org.omg.CosPersistentState.NotFound if there is no matching storage object.
     */
    public Object
    find_by_key(String[] fields_names,
                String[] fields_types,
                java.lang.Object[] key_values)
    throws org.omg.CosPersistentState.NotFound
    {
        javax.jdo.PersistenceManager pm = null;
        javax.jdo.Extent ext = null;
        javax.jdo.Query q = null;
        String filter = null,
               params = null;
        java.util.Collection c = null;
        java.lang.Class clazz = null;
        java.lang.Object[] query_values = null;

        // Get the persistence manager
        pm = ((org.objectweb.openccm.services.pss.jdo.api.CatalogBase) get_catalog()).
                get_persistence_manager();

        ((org.objectweb.openccm.services.pss.jdo.api.CatalogBase) get_catalog()).begin_tx();

        // Build an extent to work on
        clazz = ((org.objectweb.openccm.services.pss.jdo.api.CatalogBase) get_catalog()).
                    get_connector().get_storage_object_factory(get_st_rid());
        ext = pm.getExtent(clazz, false);

        // Create the query
        filter = "_sh_rid == sh_rid_param & ";
        params = "String sh_rid_param, ";
        for (int i=0; i<fields_names.length; i++)
        {
            filter += fields_names[i] + "==" + fields_names[i] + "_param";
            params += fields_types[i] +" " + fields_names[i] + "_param";
            if (i < fields_names.length-1)
            {
                filter += " & ";
                params += ", ";
            }
        }
        q = pm.newQuery(ext, filter);
        q.declareParameters(params);

        // Construct query parameter values array
        query_values = new java.lang.Object[key_values.length+1];
        query_values[0] = get_rid();
        for (int i=0; i<key_values.length; i++)
        {
            query_values[i+1] = key_values[i];
        }
        // Execute the query
        c = (java.util.Collection) q.executeWithArray(query_values);

        if (c.size() == 1)
        {
            java.util.Iterator it = c.iterator();
            org.objectweb.openccm.services.pss.common.api.StorageObject so = null;

            so = (org.objectweb.openccm.services.pss.common.api.StorageObject) it.next();
            so.initialize(this);
            return so;
        }

        throw new org.omg.CosPersistentState.NotFound();
    }
}
