/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.gui.icon;

/** The console's imports */
import org.objectweb.util.browser.naming.api.Entry;
import org.objectweb.util.browser.api.IconFactory;
import org.objectweb.util.browser.api.BrowserProperty;
import org.objectweb.util.browser.gui.common.DefaultPropertyContainer;

/**
 *
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */

public class IconPropertyContainer extends DefaultPropertyContainer {

    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default contstructor
     * @param loader The object to use to load new configuration
     */
    public IconPropertyContainer(BrowserProperty loader) {
        super(loader);
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Tries to load an element for the associated class name.
     * @param className The name of the class 
     * @return The founded entry or null
     */
    protected Entry getElement(String className) {
        return loader_.getIcon(className);
    }

    /**
     * Adds the iconFactory to the container.
     *
     * @param id The name of the entry to be retrieved.
     * @param object The iconFactory to add
     * 
     */
    protected void addEntry(String id, IconFactory object) {
        super.addEntry(id, object);
    }

    // ==================================================================
    //
    // Surcharging public methods for DefaultContextContainer class.
    //
    // ==================================================================

    /**
     * Adds the object to the container.
     *
     * This method does not modify the given name and the target context.
     *
     * @param id The name of the entry to be retrieved.
     * @param object The object to add
     * 
     */
    public void addEntry(String id, Object object) {
        if (object != null) {
            addEntry(id, (IconFactory) object);
        }
    }

}
