/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.gui.panel;

/** To use the AssociatedPanel interface */
import org.objectweb.util.browser.api.AssociatedPanel;

/** To use the PropertyLoader interface */
import org.objectweb.util.browser.api.BrowserProperty;

/** To use the Entry interface */
import org.objectweb.util.browser.naming.api.Entry;

/** To use the PanelFactory interface */
import org.objectweb.util.browser.api.PanelFactory;

/** To use the AssociatedElementImpl class */
import org.objectweb.util.browser.gui.common.AssociatedElementImpl;

/** To use the DynamicTree class */
import org.objectweb.util.browser.gui.core.DynamicTree;

/** To use the TreeView class */
import org.objectweb.util.browser.gui.common.TreeView;

/**
 * Implementation of AssociatedPanel API 
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class AssociatedPanelImpl
    extends AssociatedElementImpl
    implements AssociatedPanel {

    /** The tree */
    protected DynamicTree tree_ = null;

    /**
     * Constructs a AssociatedPanelImpl
     * @param loader The propertyLoader to use to load new configuration
     * @param tree The associated tree
     */
    public AssociatedPanelImpl(BrowserProperty loader, DynamicTree tree) {
        super();
        context_ = new PanelPropertyContainer(loader);
        tree_ = tree;
    }

    /** 
     * Returns the menu associates to the node
     * Equivalent to a getMenu(node,false) call
     *
     * @param node The node 
     * @return The associated panel or null if no context is found
     */
    public NodeViewPanel getPanel(Object node) {
        return getPanel(node, false);
    }

    /** 
     * Returns the panel associates to the node
     *
     * @param node The node 
     * @param disabledJavaLangObject If true, then java.lang.Object is not consider as a valid entry
     * @return The associated panel or null if no context is found
     */
    public NodeViewPanel getPanel(Object node,boolean disabledJavaLangObject) {
        if (context_ != null) {
            Entry entry = context_.getRecursiveProperty(node);
            if (entry != null && !(entry.getOWName().getOWId().equals("java.lang.Object") && disabledJavaLangObject)) {
                PanelFactory panelFactory = (PanelFactory) entry.getOWValue();
                NodeViewPanel nodeViewPanel = panelFactory.newPanel(node);
                if (nodeViewPanel != null) {
                    nodeViewPanel.setTreeView(new TreeView(tree_));
                    return nodeViewPanel;
                }
            }
        }
        return null;
    }

}
