/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.naming.api;

/**
 * Standard interface for {@link Context Context} iterators.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * @version 0.1
 */

public interface EntryIterator
{
    /**
     * The standard name of this interface to use
     * in the context of the Fractal framework.
     */
    static final String ENTRY_ITERATOR = EntryIterator.class.getName();

    /**
     * Returns true if the iteration has more entries.
     *
     * In other words, returns true if next would return an entry
     * rather than throwing an exception.
     *
     * @return true if the iterator has more entries.
     */
    boolean hasNext();

    /**
     * Returns the next entry in the interation.
     *
     * @return The next entry in the iteration.
     *
     * @exception NoSuchElementException Iteration has no more entries.
     */
    Entry next();

    /**
     * Removes from the underlying collection the last entry returned by
     * the iterator (optional operation). This method can be called only
     * once per call to next. The behavior of an iterator is unspecified
     * if the underlying collection is modified while the iteration is
     * in progress in any way other than by calling this method.
     *
     * @exception UnsupportedOperationException
     *            If the remove operation is not supported by
     *            this EntryIterator.
     *
     * @exception IllegalStateException
     *            If the next method has not yet been called,
     *            or the remove method has already been called
     *            after the last call to the next method.
     */
    void remove();
}
