/*===========================================================================

ObjectWeb Naming Context Framework
Copyright (C) 2002 USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.util.browser.naming.wrappers.common;

/** To use the EntryFactory interface. */
import org.objectweb.util.browser.naming.api.EntryFactory;

/** To use the Entry interface. */
import org.objectweb.util.browser.naming.api.Entry;

/** To use the Name interface. */
import org.objectweb.util.browser.naming.api.Name;

/** To use the Context interface. */
import org.objectweb.util.browser.naming.api.Context;

/**
 * Default basic implementation of the EntryFactory interface.
 *
 * This factory creates DefaultEntry instances.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * @version 0.1
 */
public class DefaultEntryFactory 
    implements EntryFactory {
	
    // ==================================================================
    //
    // No internal state.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Constructs a DefaultEntryFactory.
     */
    public DefaultEntryFactory() {
    }

    // ==================================================================
    //
    // No internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods for interface EntryFactory.
    //
    // ==================================================================

    /**
     * Creates a new {@link Entry Entry} with a value, a name, and a context.
     *
     * The value, name, and context of the created {@link Entry Entry}
     * are set respectively to the given value, name, and context.
     *
     * @param value The value of the {@link Entry Entry} to create.
     * @param name The name of the {@link Entry Entry} to create.
     * @param context The context of the {@link Entry Entry} to create.
     *
     * @return The created {@link Entry Entry}.
     *
     * @postcondition
     *        return.getOWValue() == value
     *  and    return.getOWName() == name
     *  and return.getOWContext() == context;
     */
    public Entry newOWEntry(Object value, Name name, Context context) {
        return new DefaultEntry(value, name, context);
    }
}
