/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Offroy.
Contributor(s): ______________________________________.

====================================================================*/
package org.objectweb.util.monolog.provider.lib.topics;

import java.util.HashMap;


/**
 * @author Jerome Offroy
 * 
 *  this class is used to store the TopicsValue and allows getting  entry by ref or dy name 
 */
public class TopicsMap implements TopicsPool {
    /**
     * internals HashMap and ArrayList
     */
     private HashMap binding_name = new HashMap();
     private HashMap binding_desc = new HashMap();
     private HashMap binding_ref = new HashMap();

    /**
     * Constructor for TopicsMap.
     */
    public TopicsMap() {
    }
    
    /**
     * get name associated to a Topic by reference.
     * @param ref
     * @return String
     */
    public String getName(Class ref) {
        return (String) binding_name.get(ref);
    }

    /**
     * getDescription of a Topic by name.
     * @param name
     * @return String[]
     */
    public String[] getDescription(String name) {
        return (String[]) binding_desc.get(name);
    }

    public String[] getAllName() {
        Object[] tmp = binding_name.values().toArray();
        String res[] = new String[tmp.length];
        for (int i = 0; i < tmp.length; i++)
            res[i] = (String) tmp[i];
        return res;
    }

    /**
     *  put a new TopicsValue into referential .
     * @param value the TopicsValue to add
     * @return int the hashcode for the new entry
     */
    public int put(TopicsValue value) {
        binding_name.put(value.getRef(), value.getName());
        binding_desc.put(value.getRef(), value.getDescription());
        binding_ref.put(value.getName(), value.getRef());
        return 0;
    }

    /**
     * put a new TopicsValue into referentia (as attributes).
     * @param ref
     * @param name
     * @param description
     * @return int the hashcode for the new entry
     */
    public int put(Class ref, String name, String[] description) {
        return put(new TopicsValue(ref,name,description));
    }

    public HashMap getTopicsByRef() {
        return binding_name;
    }
}
