/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA - USTL - LIFL - GOAL
Contact: openccm-team@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): .

====================================================================*/

package org.objectweb.ccm.simple;

/**
 * Various invalid home installation.
 */
public class Install
{
  /**
   * The bootstrap of the application.
   */
  public static void
  main(String[] args)
    throws Exception
  {
      // Init the ORB.
      System.out.println("INSTALL: Initializing the ORB...");
    
      // TODO: Need to report this ORB.init() problem to OpenORB developers!
      // Due to an OpenORB problem, the following line:
      //   org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init(args, null);
      // are replaced by the next line.
    
      // Init the ORB.
      args = org.objectweb.ccm.CORBA.TheORB.initialize(args);

      // Init the OpenCCM runtime.
      org.objectweb.ccm.Components.Runtime.init();

      // Obtain the ORB.
      org.omg.CORBA.ORB orb = org.objectweb.ccm.CORBA.TheORB.getORB();

      // Obtain the Name Service.
      System.out.println("INSTALL: Obtaining the Name Service...");
      org.omg.CORBA.Object obj = orb.resolve_initial_references("NameService");
      org.omg.CosNaming.NamingContext nc = org.omg.CosNaming.NamingContextHelper.narrow(obj);

      // Obtain the component servers.
      System.out.println("INSTALL: Obtaining the Component Server...");
      org.omg.CosNaming.NameComponent[] ncomp = new org.omg.CosNaming.NameComponent[1];
      ncomp[0] = new org.omg.CosNaming.NameComponent("ComponentServer", "");
      obj = nc.resolve(ncomp);
      org.objectweb.ccm.Deployment.Server server = org.objectweb.ccm.Deployment.ServerHelper.narrow(obj);

      // Obtain the container homes and archive installators.
      org.omg.Components.Deployment.ComponentServer server_cs = server.provide_component_server();
      org.omg.Components.Deployment.ComponentInstallation server_inst = server.provide_install();

      // Install archives.
      System.out.println("INSTALL: Installing the archive...");
      // get the current directory and store it as a String
      String demoPath = null;
      try
      {
          demoPath = new java.io.File(".").getCanonicalPath()+ java.io.File.separator ;
      }
      catch(Exception e)
      {
          e.printStackTrace();
      }

      server_inst.install("simple", demoPath + "./archives/simple.jar");

      // instantiate a container on each server.
      System.out.println("INSTALL: Creating a container...");
      org.omg.Components.Deployment.Container server_cont =
        server_cs.create_container(new org.omg.Components.ConfigValue[0]);

      // Install homes.
      System.out.println("INSTALL: Instantiating the home...");
      org.omg.Components.CCMHome h = null;

      org.omg.Components.ConfigValue[] config = new org.omg.Components.ConfigValue[0];

      try
      {
          System.out.println("INSTALL: Call install_home with a correct home executor entry point...");
          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home",
                                       config);
          System.out.println("INSTALL: Home installed correctly.");
      }
      catch (Exception exc) 
      {
          System.out.println("INSTALL: ERROR: " + exc.getMessage() + " was thrown!!!");
          System.exit(-1);
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an unknown implementation id...\n");

          h = server_cont.install_home("unknown_uuid",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::UnknownImplId must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.UnknownImplId exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an unknown home executor entry point...\n");

          h = server_cont.install_home("simple",
                                       "UnknownClass.create_home",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::ImplEntryPointNotFound must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.ImplEntryPointNotFound exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an unknown home executor entry point...\n");

          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.unknown_method",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::ImplEntryPointNotFound must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.ImplEntryPointNotFound exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an existing home executor entry point but invalid signature...\n");

          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home_private",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::ImplEntryPointNotFound must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.ImplEntryPointNotFound exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an existing home executor entry point but invalid signature...\n");

          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home_not_static",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::ImplEntryPointNotFound must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.ImplEntryPointNotFound exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an existing home executor entry point but invalid signature...\n");

          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home_with_invalid_return_type",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::ImplEntryPointNotFound must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.ImplEntryPointNotFound exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an existing home executor entry point but invalid signature...\n");

          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home_with_parameter",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::ImplEntryPointNotFound must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.ImplEntryPointNotFound exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an existing home executor entry point function but thrown an exception...\n");

          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home_thrown_an_exception",
                                       config);

          System.out.println("\nINSTALL: ERROR: Components::Deployment::Installation must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.InstallationFailure exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      config = new org.omg.Components.ConfigValue[1];
      config[0] = new org.objectweb.ccm.Components.ConfigValueImpl();
      config[0].name = "home_script";
      config[0].value = orb.create_any();

      try
      {
          System.out.println("\nINSTALL: Call install_home with an empty 'home_script' configuration value...");
          config[0].value.insert_string("");
          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home",
                                       config);
          System.out.println("\nINSTALL: ERROR: Components::Deployment::InstallationFailure must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.InstallationFailure exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an invalid type for the 'home_script' configuration value...");
          config[0].value.insert_long(10);
          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home",
                                       config);
          System.out.println("\nINSTALL: ERROR: Components::Deployment::InvalidConfiguration must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.InvalidConfiguration exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      try
      {
          System.out.println("\nINSTALL: Call install_home with an invalid value for the 'home_script' configuration value...");
          config[0].value.insert_string("invalid script");
          h = server_cont.install_home("simple",
                                       "org.objectweb.ccm.simple.ServerHomeImpl.create_home",
                                       config);
          System.out.println("\nINSTALL: ERROR: Components::Deployment::InvalidConfiguration must be thrown!!!");
          System.exit(-1);
      }
      catch (org.omg.Components.Deployment.InvalidConfiguration exc) 
      {
          System.out.println("\nINSTALL: OK " + exc.getMessage() + " was thrown.");
      }

      System.out.println("\nINSTALL: All install_home tests were OK.");
      System.exit(0);
  }
}






