/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Contreras
Contributor(s): ___________________________________________________.

====================================================================*/

package org.objectweb.openccm.deployment.gui;

/**
 * This utils class is an helper for any File operations
 *      opening
 *
 * @author <a href="mailto:Christophe.Contreras@lifl.fr">Christophe Contreras</a>
 *
 */
public class FileOperations
{
    /**
     * File opening
     *
     * @param file The file to open
     * @param frame The frame to send result to
     */
    static void
    open_file(
        java.io.File file,
        org.objectweb.apollon.gui.ApollonFrame frame)
    {
        if (! file.exists()
            || ! file.isFile()
            )
        {
            System.err.println("File : "+file.getName()+" : ignored");
            return;
        }
        
        if (file.getName().toLowerCase().endsWith("cad")
            || file.getName().toLowerCase().endsWith("csd")
            || file.getName().toLowerCase().endsWith("ccd")
            || file.getName().toLowerCase().endsWith("cpf")
            || file.getName().toLowerCase().endsWith("npd")
            )
        {
            frame.open_file(file);
        }
        if (file.getName().toLowerCase().endsWith("aar")
            || file.getName().toLowerCase().endsWith("car")
            || file.getName().toLowerCase().endsWith("zip")
            )
        {
            try
            {
                // Open the ZIP file
                java.util.zip.ZipInputStream in 
                 = new java.util.zip.ZipInputStream(
                    new java.io.FileInputStream(file.getAbsolutePath())
                    );
                // Go through the entries
                java.util.zip.ZipEntry entry
                 = in.getNextEntry();
                while (in.available() == 1)
                {
                    java.io.File file_entry
                     = new java.io.File(entry.getName());

                    if (entry.isDirectory())
                    {
                        file_entry.mkdir();
                    } else {
                        if (entry.getName().indexOf("/")>-1)
                        {
                            java.io.File file_dir
                             = new java.io.File(
                                entry.getName().substring(
                                    0,
                                    entry.getName().lastIndexOf("/")
                                    )
                                );
                            file_dir.mkdir();
                        }
                        // Opens an output file stream
                        java.io.OutputStream out
                         = new java.io.FileOutputStream(file_entry);
                        // Transfer bytes from ZIP to output file
                        byte[] buf = new byte[1024];
                        int len;
                        while ((len = in.read(buf)) > 0) {
                            out.write(buf, 0, len);
                        }
                        // Close the file outut stream
                        out.close();
                        // opens the file in the GUI
                        frame.open_file(new java.io.File(entry.getName()));
                    }
                    entry = in.getNextEntry();
                }
                in.close();
            } catch (java.util.zip.ZipException exc) {
                System.err.println("*** ZIP archive file corrupted ***");
                exc.printStackTrace();
            } catch (java.io.IOException exc) {
                System.err.println("*** error during file opening ***");
                exc.printStackTrace();
            }
        }
    }
}