/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle, Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.ast.lib;

// Package dependencies.
import org.objectweb.openccm.ast.api.DeclarationKind;
import org.objectweb.openccm.ast.api.Declaration;
import org.objectweb.openccm.ast.api.DelegationList;
import org.objectweb.openccm.ast.api.SegmentDecl;
import org.objectweb.openccm.ast.api.CategoryKind;

/**
 * ExecutorDeclImpl is a wrapper class for CIDL executor declarations.
 *
 *
 * Inherits from:
 * - CidlScopeImpl as executors are also IDL scopes.
 * - ExecutorDecl as OMG IDL for CIDL executor declarations.
 *
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.2
 */

public class ExecutorDeclImpl
     extends CidlScopeImpl
  implements org.objectweb.openccm.ast.api.ExecutorDecl
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** List of feature delegations. */
    private DelegationListImpl feature_delegation_;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The constructor with the parent scope.
     *
     * @param rep The repository of the declaration.
     * @param parent The parent scope of the exception declaration.
     */
    public
    ExecutorDeclImpl(Repository rep,
                     ScopeImpl parent)
    {
        // Call the ScopeImpl constructor.
        super(rep, parent);

        // Init internal state.
        feature_delegation_ = new DelegationListImpl();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Internal methods for DeclarationImpl.
    //
    // ==================================================================

    /**
     * Loads infos of the CORBA 3.0 ExceptionDef.
     *
     * @param contained The ExceptionDef to load.
     */
    protected void
    load(org.omg.CORBA.Contained contained)
    {
      // TODO
    }

    /**
     * Loads infos of the CORBA 3.0 ExceptionDef.
     *
     * @param contained The ExceptionDef to load.
     */
    protected void
    loadAsMapping(org.omg.CORBA.Contained contained)
    {
      // TODO
    }

    /**
     * Obtain its CORBA 3.0 Contained reference.
     *
     * @return The Contained object associated with the exception
     *         declaration.
     */
    protected org.omg.CORBA.Contained
    getContained()
    {
       return null;
    }

    // ==================================================================
    //
    // Internal methods for ScopeImpl.
    //
    // ==================================================================

    /**
     * Obtain its CORBA 3.0 Container reference.
     *
     * @return The Container object associated with the exception
     *          declaration.
     */
    protected org.omg.CORBA.Container
    getContainer()
    {
        return null;
    }

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL org.objectweb.openccm.ast.api.WithDependencies
    //
    // ==================================================================

    /**
     * Obtain the declaration external dependencies.
     *
     * Note: for scopes, contained objects are not considered
     *       as dependencies.
     *
     * @return The list of dependencies as an array of Declaration.
     */
    public Declaration[]
    getDependencies()
    {
        if (dependencies_!=null)
            return dependencies_;

        java.util.List exec_depend = new java.util.ArrayList();
        Declaration[] depend = null;

        // Feature delegation
        // Nothing to do for the moment

        // Contents
        Declaration[] decls = getContents(true, DeclarationKind.dk_all);
        for (int i=0; i<decls.length; i++)
        {
            depend = decls[i].getDependencies();
            for (int j=0; j<depend.length; j++)
            {
                if ( (!containsDecl(depend[j])) &&
                     (depend[j] != this) &&
                     (exec_depend.indexOf(depend[j]) == -1) )
                    exec_depend.add(depend[j]);
            }
        }

        dependencies_ = (Declaration[])exec_depend.toArray(new Declaration[0]);
        return dependencies_;
    }

    // ==================================================================
    //
    // Methods for OMG IDL org.objectweb.openccm.ast.api.Declaration
    //
    // ==================================================================

    /**
     * Obtain its DeclarationKind.
     *
     * @return The DeclarationKind of the object.
     */
    public long
    getDeclKind()
    {
        return DeclarationKind.dk_executor;
    }

    /**
     * Close the exception scope.
     */
    public void
    create()
    {
        // Call the Cidl scope method
        super.create();

      // TODO check if the executor declaration is correct
    }

    // ==================================================================
    //
    // Methods for OMG IDL org.objectweb.openccm.ast.api.Scope
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for OMG IDL org.objectweb.openccm.ast.api.ExecutorDecl
    //
    // ==================================================================

    /**
     * Obtain the associated composition category.
     *
     * @return The associated composition category.
     */
    public CategoryKind
    getCompositionKind()
    {
        return ((org.objectweb.openccm.ast.api.CompositionDecl)getParent().getParent()).getCategoryKind();
    }

    /**
     * Obtain the feature delegation list.
     *
     * @return The feature delegation list.
     */
    public DelegationList
    getFeatureDelegationList()
    {
        return feature_delegation_;
    }

    /**
     * Start a new CIDL segment declaration.
     *
     * @param name The name of the CIDL segment declaration.
     *
     * @return The new created SegmentDecl.
     */
    public SegmentDecl
    startSegment(String name)
    {
        SegmentDecl decl = new SegmentDeclImpl(getRepository(), this);
        decl.setName(name);
        return decl;
    }
}
