/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.ast.utils.lib;

// Package dependencies.
import org.objectweb.openccm.ast.api.DeclarationKind;
import org.objectweb.openccm.ast.api.Declaration;
import org.objectweb.openccm.ast.api.ComponentDecl;
import org.objectweb.openccm.ast.api.HomeExecutorDecl;
import org.objectweb.openccm.ast.api.ExecutorDecl;
import org.objectweb.openccm.ast.api.SegmentDecl;
import org.objectweb.openccm.ast.api.InterfacePortDecl;
import org.objectweb.openccm.ast.api.EventPortDecl;
import java.util.List;
import java.util.ArrayList;

/**
 * This class provides usefull methods for components.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class ExecutorInfo
  implements org.objectweb.openccm.ast.utils.api.ExecutorInfo
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /** The executor declaration. */
    private ExecutorDecl exec_;

    /** The binding component declaration. */
    private ComponentDecl comp_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     *
     * @param exec - The executor declaration.
     **/
    public ExecutorInfo(ExecutorDecl exec)
    {
        HomeExecutorDecl home_exec = null;

        // Init internal states
        exec_ = exec;

        // Get the managed component
        home_exec = (HomeExecutorDecl) exec.getParent();
        comp_ = home_exec.getHomeType().getManagedComponent();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    /**
     * Remove implemented facets for the list.
     */
    protected void
    removeSegmentFacets( SegmentDecl seg,
                         List implemented_facets )
    {
        ComponentDecl current = null;
        String[] facets = null;
        String[] sinks = null;

        // For each facet implemented,
        // remove the corresponding interface from the list
        facets = seg.getFacetList().getStrings();
        for (int i=0; i<facets.length; i++)
        {
            InterfacePortDecl itf_port = null;

            current = comp_;
            while ((itf_port == null) && (current != null))
            {
                itf_port = (InterfacePortDecl) current.lookup(facets[i]);
                // Search facet declaration in the base component
                current = current.getBaseComponent();
            }
            implemented_facets.remove(itf_port);
        }

        // For each sink implemented,
        // remove the corresponding interface from the list
        sinks = seg.getSinkList().getStrings();
        for (int i=0; i<sinks.length; i++)
        {
            EventPortDecl event_port = null;

            current = comp_;
            while ((event_port == null) && (current != null))
            {
                event_port = (EventPortDecl) current.lookup(sinks[i]);
                // Search sink declaration in the base component
                current = current.getBaseComponent();
            }
            implemented_facets.remove(event_port);
        }
    }

    // ==================================================================
    //
    //  Public methods for org.objectweb.openccm.generator.cif.api.ComponentInfo.
    //
    // ==================================================================

    /**
     * Get facets and sinks implemented directly by the main segment.
     * This not include facets and sinks implemented by component's segments.
     *
     * @return The facets (or sinks) list.
     */
    public Declaration[]
    getMainSegmentFacets()
    {
        Declaration[] decls = null;
        List implemented_facets = new ArrayList();

        // Get ProvidesDecl and ConsumesDecl to build a list
        decls = comp_.getContents( false,
                                   DeclarationKind.dk_provides
                                   + DeclarationKind.dk_consumes );
        for (int i=0; i<decls.length; i++)
        {
            implemented_facets.add( decls[i] );
        }

        // Get segments and remove implemented facets & sinks
        decls = exec_.getContents(true, DeclarationKind.dk_segment);
        for (int i=0; i<decls.length; i++)
        {
            removeSegmentFacets( (SegmentDecl) decls[i],
                                 implemented_facets );
        }

        return (Declaration[]) implemented_facets.toArray(new Declaration[0]);
    }

    // ==================================================================
    //
    //  Public methods.
    //
    // ==================================================================

}
