/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): Sylvain Leblanc.

====================================================================*/

package org.objectweb.openccm.generator.common.api;

/**
 * This interface is a Velocity Wrapper (http://jakarta.apache.org/Velocity).
 **/
public interface Generator
{
    /**
     * Sets the file ressource loader path.
     *
     * @param path - The path from where files will be loaded.
     **/
    public void
    setRessourcePath(java.util.List v);

    /**
     * Sets the name of the local Velocimacro library template.
     *
     * @param name - The local Velocimacro library template path.
     **/
    public void
    setLibrary(java.util.List v);

    /**
     * Sets the current context.
     *
     * @param context - The context to be set.
     **/
    public void
    setContext(org.apache.velocity.context.Context context);

    /**
     * Disable the log system.
     **/
    public void
    disableLog();
    
    /**
     * Initialize the generator.
     **/
    public void
    init();

    /**
     * Open a new generation stream.
     *
     * @param filename - The name of the file into generation will be done.
     * @param id - An identifiant for this stream.
     */
    public void
    open(String filename, String id);

    /**
     * Close a generation stream and
     * eventually indent the generated file.
     *
     * @param id - The identifiant of the file to close.
     * @param indent - True if the file must be indented, else false.
     */
    public void
    close(String id, boolean indent);

    /**
     * Close a generation stream and indent the generated file.
     *
     * @param id - The identifiant of the file to close.
     */
    public void
    close(String id);

    /**
     * Switch generation output to file with identifiant id.
     *
     * @param id - The identifiant of the file to close.
     */
    public void
    switchToFile(String id);

    /**
     * Gets a value from the context.
     *
     * @param key - The name to key the provided value with.
     *
     * @return The associated value.
     **/
    public Object
    get(String key);

    /**
     * Adds a name/value pair to the context.
     *
     * @param key - The name to key the provided value with.
     *        name - The corresponding value.
     **/
    public void
    put(String key, Object value);

    /**
     * Removes the value associated with the specified key from the context.
     *
     * @param key - The name of the value to remove.
     **/
    public void
    remove(Object key);

    /**
     * Uses velocity to map a template file.
     *
     * @param template_name - The name of the template file.
     **/
    public void
    map_file(String template_name);

    /**
     * Uses velocity to map a template file.
     *
     * @param template_name - The name of the template file.
     * @param id - The identifiant of the output file.
     **/
    public void
    map_file(String template_name, String id);

    /**
     * Uses velocity to map a currently registered Velocimacro.
     *
     * @param macro_name - The name of the macro to invoke (map)
     **/
    public void
    map(String macro_name);

    /**
     * Uses velocity to map a currently registered Velocimacro.
     *
     * @param macro_name - The name of the macro to invoke (map)
     * @param context - The context used to map the macro.
     **/
    public void
    map(String macro_name, org.apache.velocity.context.Context context);
    
    /**
     * Uses velocity to map a currently registered Velocimacro.
     *
     * @param macro_name - The name of the macro to invoke (map)
     * @param id - The identifiant of the output file.
     **/
    public void
    map(String macro_name, String id);

    /**
     * Print immediatly the text in the output stream.
     *
     * @param text - The text to be written.
     **/
    public void
    print(String text);

    /**
     * Print immediatly the text in the output stream.
     *
     * @param text - The text to be written.
     * @param id - The identifiant of the output file.
     **/
    public void
    print(String text, String id);

    /**
     * Return a string if nb spaces.
     *
     * @param nb - The number of spaces to print.
     *
     * @return A string containing nb spaces.
     **/
    public String
    print_spaces(int nb);
}
