/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.openccm.task;

//Package dependencies
import java.util.Map;

/**
 * This is a base class for Compiler applications.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 * 
 * @version 0.1
 */
public class CompilerBase
     extends LauncherApplication
{
    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    /** The file to feed. */
    private String file_;

    /** Flag to include OMG IDL3 macro or not. */
    private boolean idl3_macro_;
    
    /** To manage CPP options. */
    private CPPoptions cpp_options_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     * 
     * @param project_properties - Properties of the Ant Project.
     */
    public CompilerBase(Map project_properties)
    {
        // Call Launcher constructor
        super(project_properties);
        
        // Init internal states
        file_ = null;
        idl3_macro_ = true;
        cpp_options_ = null;
    }
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    
    /**
     * Disable the -D__OMG_IDL_3__ macro.
     */
    public void
    disableIDL3macro()
    {
        idl3_macro_ = false;
    }
    
    /**
     * Configure the task.
     */
    public void
    configure()
    {
        if (idl3_macro_)
        {
            addProperty("__OMG_IDL_3__", "");
        }
        if (cpp_options_ != null)
        {
            addArgument( cpp_options_.getCPParguments() );
        }
        addArgument(file_);
        addProperty( "OpenCCM_CONFIG_DIR",
                     project_properties_.getProperty("OpenCCM_CONFIG_DIR") );
    }
    
    /**
     * Set the name of the file to feed.
     *
     * @param file - The file to feed.
     */
    public void
    setFile(String file)
    {
        this.file_ = file;
    }

    /**
     * Create an inner element for PreProcessor Options.
     */
    public CPPoptions
    createCpp()
    {
        cpp_options_ = new CPPoptions(); 
        return cpp_options_;
    }

}
