/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ________________________________________.

====================================================================*/

package org.objectweb.openccm.task;

// Package dependencies
import java.util.Iterator;
import java.util.Map;


/**
 * This task generates OMG IDL 2.4 from the OpenCCM Interface Repository.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 * 
 * @version 0.1
 */
public class IR3toIDL2
     extends LauncherApplication
{
    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    /** The output file name. */
    private String dest_file_;

    /** The scope to generate. */
    private String scope_;

    /** List of files to include. */
    private java.util.List includes_;

    /** List of user files to include. */
    private java.util.List user_includes_;

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * The default constructor.
     * 
     * @param project_properties - Properties of the Ant Project.
     */
    public IR3toIDL2(Map project_properties)
    {
        // Call CompilerBase constructor
        super(project_properties);
        
        // Init internal states
        dest_file_ = "generated.idl";
        scope_ = null; 
        includes_ = new java.util.ArrayList();
        user_includes_ = new java.util.ArrayList();
    }
    
    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================
    
    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================
    
    /**
     * Configure the task.
     */
    public void
    configure()
    {
        Iterator it = null;
        
        setXmlFile( project_properties_.getProperty("OpenCCM_launcher_dir") + "/IR3toIDL2.xml" );
        addProperty( "OpenCCM_CONFIG_DIR",
                     project_properties_.getProperty("OpenCCM_CONFIG_DIR") );
        // Add destination file
        addArgument("-o");
        addArgument(dest_file_);
        // Add include declarations
        for (it = includes_.iterator(); it.hasNext(); )
        {
            addArgument("-i");
            addArgument( (String) it.next() );
        }
        // Add user include declarations
        for (it = user_includes_.iterator(); it.hasNext(); )
        {
            addArgument("-ipath");
            addArgument( (String) it.next() );
        }
        // Add target scope
        addArgument(scope_);
    }

    /**
     * Set Java mapping output directory.
     * 
     * @param outputdir - The output directory name.
     */
    public void
    setDestfile(String filename)
    {
        dest_file_ = filename;
    }
    
    /**
     * Set the scope to generate.
     * 
     * @param scope - The scope to generate.
     */
    public void
    setScope(String scope)
    {
        scope_ = scope;
    }
    
    /**
     * Add an include declaration in the generated file.
     * 
     * @param str - The declaration name to include.
     */
    public void
    addConfiguredInclude(StringType str)
    {
        includes_.add(str.getName()); 
    }
    
    /**
     * Add a user include declaration in the generated file.
     * 
     * @param str - The declaration name to include.
     */
    public void
    addConfiguredUserinclude(StringType str)
    {
        user_includes_.add(str.getName()); 
    }
    
}
