# ====================================================================
#
# OpenCCM: The Open CORBA Component Model Platform
# Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
# Contact: openccm@objectweb.org
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
# USA
#
# Initial developer(s): Pierre Carpentier.
# Contributor(s): ______________________________________.
#
# --------------------------------------------------------------------
# $Id: CORBA3Feeder.cs,v 1.1 2004/04/15 09:09:01 carpentier Exp $
# ====================================================================
#
#  This class feeds the AST from the differents elements in the
#  UML repository. This file is build according to the UML Profile
#  for CORBA Components (Version 3.1).
#
# ====================================================================

import NotCreatedException;
import CORBA2Feeder;

class CORBA3Feeder (CORBA2Feeder.CORBA2Feeder)
{

    # =================================================================
    #   Empty Constructor for the CORBA3Feeder.
    # =================================================================
    proc __CORBA3Feeder__(self)
    {
        self.__CORBA2Feeder__();
    }


    # =================================================================
    #   4.1.2.1 - Component
    # =================================================================
    proc createCORBAComponent (self, element, currentScope)
    {
        try {
            compo = currentScope.declareComponent(element.getName());
            compo.create();
            for g in element.getGeneralization().toArray() {
                if (self.umlOperations.isStereotyped(g.getParent(), "CORBAInterface")) {
                    compo.getSupportedInterfaceList().add(g.getParent());
                } else if (self.umlOperations.isStereotyped(g.getParent(), "CORBAComponent")) {
                    compo.setBaseComponent(self.getType(g.getParent()));
                }
            }
            self.create(element.getFeature().toArray(), compo);
            compo.create();
            self.putType(element, compo);
            # println("> Component created : ", element.getName());
        } catch (NotCreatedException.NotCreatedException nce) {
            compo.destroy();
            throw nce;
        }
    }


    # =================================================================
    #   4.1.2.2 - Facet and Receptacle - CORBAProvides
    # =================================================================
    proc createCORBAProvides (self, element, currentScope)
    {
        connect = element.getConnection();
        interface = "notset";
        compo = "notset";
        name = "";
        if (self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAInterface")
            || self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAHome")) {
            interface = self.getType(connect.get(0).getParticipant());
            compo = self.getType(connect.get(1).getParticipant());
            name = connect.get(0).getName();
        } else {
            interface = self.getType(connect.get(1).getParticipant());
            compo = self.getType(connect.get(0).getParticipant());
            name = connect.get(1).getName();
        }
        provides = compo.startProvides(name);
        provides.setInterface(interface);
        provides.create();
        # println("> Provides created : ", name);
    }


    # =================================================================
    #   4.1.2.2 - Facet and Receptacle - CORBAUses
    # =================================================================
    proc createCORBAUses (self, element, currentScope)
    {
        connect = element.getConnection();
        interface = "notset";
        compo = "notset";
        name = "";
        if (self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAInterface")
            || self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAHome")) {
            interface = self.getType(connect.get(0).getParticipant());
            compo = self.getType(connect.get(1).getParticipant());
            name = connect.get(0).getName();
        } else {
            interface = self.getType(connect.get(1).getParticipant());
            compo = self.getType(connect.get(0).getParticipant());
            name = connect.get(1).getName();
        }
        uses = compo.startUses(name);
        multiple = "no";
        for tv in element.getTaggedValue().toArray() {
            if (tv.getType().getTagType() == "CORBAIsMultiple") {
                multiple = tv.getDataValue();
            }
        }
        if (multiple == "yes") {
            uses.setMultiple();
        }
        uses.setInterface(interface);
        uses.create();
        # println("> Uses created : ", name);
    }


    # =================================================================
    #   4.1.2.3 - Event
    # =================================================================
    proc createCORBAEvent (self, element, currentScope)
    {
        try {
            event = currentScope.declareEvent(element.getName());
            if (element.isAbstract())
                event.setAbstract(true);
            # Not present in the UML Profile for CORBA.
            #if (element.is_custom())
            #    event.setCustom(true);
            event.create();
            for feature in element.getFeature().toArray() {
                self.createAttribute(feature, event, true);
            }
            self.createAssociationAttribute(element, event, true);
            self.putType(element, event);
            # println("> Event created : ", element.getName());
        } catch (NotCreatedException.NotCreatedException nce) {
            event.destroy();
            throw nce;
        }
    }


    # =================================================================
    #   4.1.2.3 - Event - CORBAConsumes
    # =================================================================
    proc createCORBAConsumes (self, element, currentScope)
    {
        connect = element.getConnection();
        event = "notset";
        compo = "notset";
        name = "";
        if (self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAEvent")) {
            event = self.getType(connect.get(0).getParticipant());
            compo = self.getType(connect.get(1).getParticipant());
            name = connect.get(0).getName();
        } else {
            event = self.getType(connect.get(1).getParticipant());
            compo = self.getType(connect.get(0).getParticipant());
            name = connect.get(1).getName();
        }
        consumes = compo.startConsumes(name);
        consumes.setEvent(event);
        consumes.create();
        # println("> Consumes created : ", name);
    }


    # =================================================================
    #   4.1.2.3 - Event - CORBAEmits
    # =================================================================
    proc createCORBAEmits (self, element, currentScope)
    {
        connect = element.getConnection();
        event = "notset";
        compo = "notset";
        name = "";
        if (self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAEvent")) {
            event = self.getType(connect.get(0).getParticipant());
            compo = self.getType(connect.get(1).getParticipant());
            name = connect.get(0).getName();
        } else {
            event = self.getType(connect.get(1).getParticipant());
            compo = self.getType(connect.get(0).getParticipant());
            name = connect.get(1).getName();
        }
        emits = compo.startEmits(name);
        emits.setEvent(event);
        emits.create();
        # println("> Emits created : ", name);
    }


    # =================================================================
    #   4.1.2.3 - Event - CORBAPublishes
    # =================================================================
    proc createCORBAPublishes (self, element, currentScope)
    {
        connect = element.getConnection();
        event = "notset";
        compo = "notset";
        name = "";
        if (self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAEvent")) {
            event = self.getType(connect.get(0).getParticipant());
            compo = self.getType(connect.get(1).getParticipant());
            name = connect.get(0).getName();
        } else {
            event = self.getType(connect.get(1).getParticipant());
            compo = self.getType(connect.get(0).getParticipant());
            name = connect.get(1).getName();
        }
        publishes = compo.startPublishes(name);
        publishes.setEvent(event);
        publishes.create();
        # println("> Publishes created : ", name);
    }


    # =================================================================
    #   4.1.2.4 - Component Home
    # =================================================================
    proc createCORBAHome (self, element, currentScope)
    {
        try {
            primarykey = false;
            associations = self.umlOperations.associations(element);
            for asso in associations {
                if (self.umlOperations.isStereotyped(asso, "CORBAManages")) {
                    assoManages = asso;
                    if (self.umlOperations.isStereotyped(asso, "CORBAPrimaryKey")) {
                        primarykey = true;
                    }
                }
            }
            connect = assoManages.getConnection();
            if (self.umlOperations.isStereotyped(connect.get(0).getParticipant(), "CORBAHome")) {
                managedComponent = connect.get(1).getParticipant();
            } else {
                managedComponent = connect.get(0).getParticipant();
            }
            home = currentScope.startHome(element.getName());
            mc = self.getType(managedComponent);
            home.setManagedComponent(mc);
            for g in element.getGeneralization().toArray() {
                if (self.umlOperations.isStereotyped(g.getParent(), "CORBAHome")) {
                    home.setBaseHome(self.getType(g.getParent()));
                } else if (self.umlOperations.isStereotyped(g.getParent(), "CORBAInterface")) {
                    home.getSupportedInterfaceList().add(self.getTypes(g.getParent()));
                }
            }
            if (primarykey) {
                try {
                    primary = self.getType(assoManages.getName());
                } catch (exception) {
                    primary = currentScope.declareValue(assoManages.getName());
                    if (assoManages.isAbstract())
                        primary.setAbstract(true);
                    self.createCORBAValueContents(primary, assoManages);
                    primaryKeyBase = Components.PrimaryKeyBase;
                    primary.getAbstractValueList().add(self.ast.lookupId("IDL:omg.org/Components/PrimaryKeyBase:1.0"));
                    primary.create();
                    self.putType(assoManages.getName(), primary);
                }
                home.setPrimaryKey(primary);
            }
            home.create();
            self.create(element.getFeature().toArray(), home);
            home.create();
            self.putType(element, home);
            # println("> Home created : ", element.getName());
        } catch (NotCreatedException.NotCreatedException nce) {
            home.destroy();
            throw nce;
        }
    }


    # =================================================================
    #   4.1.2.4 - Component Home - CORBAFactory
    # =================================================================
    proc createCORBAFactory (self, element, currentScope)
    {
        try {
            homeFactory = currentScope.startFactory(element.getName());
            homeFactoryParam = homeFactory.getParameterList();
            self.setOperationParameters(homeFactory, element);
            self.setOperationExceptions(homeFactory, element);
            homeFactory.create();
        } catch (NotCreatedException.NotCreatedException nce) {
            homeFactory.destroy();
            throw nce;
        }
    }


    # =================================================================
    #   4.1.2.4 - Component Home - CORBAHomeFinder
    # =================================================================
    proc createCORBAFinder (self, element, currentScope)
    {
        try {
            homeFinder = currentScope.startFinder(element.getName());
            self.setOperationParameters(homeFinder, element);
            self.setOperationExceptions(homeFinder, element);
            homeFinder.create();
        } catch (NotCreatedException.NotCreatedException nce) {
            homeFinder.destroy();
            throw nce;
        }
    }


}
