/*====================================================================

ObjectWeb Util Launcher Package.
Copyright (C) 2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Romain Rouvoy.
Contributor(s): .

--------------------------------------------------------------------
$Id: StringList.java,v 1.2 2004/02/11 17:56:16 rouvoy Exp $
====================================================================*/

package org.objectweb.util.launcher ;


import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;


/**
 * Dynamic list of strings.<BR>
 * <p>
 * this structure considers only characters list.
 * </p>
 *
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 *
 * @version 0.1
 */
public class StringList 
     extends ArrayList
{
    /**
     * Default Constructor
     *
     */
    public StringList() {
        super();
    }
    
    /**
     * Constructor based on static String array.
     * @param str the array to convert.
     */
    public StringList(String[] str) {
        super(Arrays.asList(str));
    }
    
    /**
     * Adds a new string at the end of the list
     *
     * @param value - the new element to add
     */
    public void add(String value) {
        if (!value.trim().equals(""))
            add((Object)value); 
    }

    /**
     * Adds the content of a StringList at the end of the current list
     *
     * @param value - the elements to add
     */
    public void addAll(StringList value) { 
        addAll((Collection)value);
    }

    /**
     * Converts the current list to a static String[] object
     *
     * @return a static array containing all the values of the current list
     */
    public String[] toStringArray() { 
        return (String[]) toArray(new String[0]); 
    }


    /**
     * Provides a string representation of the list
     *
     * @return a string representation
     */
    public String toString() {
        java.util.Iterator iter = super.iterator();
        StringBuffer result = new StringBuffer();
        result.append("[");
        while (iter.hasNext()) {
          String value = (String) iter.next() ;
          result.append(value);
          if (iter.hasNext()) result.append(", ");
        }
        result.append("]");
        return result.toString();
    }

    /**
     * Returns true if the two lists contain the same string values
     *
     * @param obj - the value to compare
     *
     * @return true if the list have the same content
     */
    public boolean equals(Object obj) {
        if (obj instanceof StringList) {
            StringList list = (StringList) obj;
            return super.equals(obj);
        }
        return false ;
    }
}