/*====================================================================

 ObjectWeb Util Launcher Package.
 Copyright (C) 2004 INRIA & USTL - LIFL - GOAL
 Contact: openccm@objectweb.org

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 USA

 Initial developer(s): Romain Rouvoy.
 Contributor(s): .

--------------------------------------------------------------------
$Id: ParserZeus.java,v 1.3 2004/02/27 19:07:20 rouvoy Exp $
====================================================================*/

package org.objectweb.util.launcher.parser ;


import java.util.Iterator;

import java.net.URL ;

import org.objectweb.util.launcher.LauncherException ;
import org.objectweb.util.trace.TraceSystem;


/**
 * This class is an implementation of the Parser interface for providing 
 * an XML parser using Zeus library.<BR>
 * <p>
 * This library uses the Zeus library for parsing the file.
 * </p>
 *
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 * @version 0.1
 */
public class ParserZeus
  implements Parser
{
    /** List of parsed file (with includes). */
    protected java.util.ArrayList parsed_files_ ;

    /**
     * Default constructor.
     */
    public ParserZeus() {
        parsed_files_ = new java.util.ArrayList();
    }


    /**
     * Reads a file using the Zeus library.
     *
     * @param url the url of the file to parse.
     */
    protected Launcher readFile(String url) { 
        try {
            return readFile(new java.net.URL(url)); 
        } catch (Exception ex) {
            TraceSystem.get("decoder").error("Exception raised: "+ex);
            throw new LauncherException(ex);
        }
    }

    /**
     * Reads a file using the Zeus library.
     *
     * @param url the url of the file to parse.
     */
    protected Launcher readFile(URL url) {
        TraceSystem.get("parser").info("Reading "+url+" ...");
        try {            
            return LauncherUnmarshaller.unmarshal(url.openStream()) ;
        } catch (java.io.IOException e) {
            TraceSystem.get("decoder").error("[I/O Error] : "+e);
            throw new LauncherException(e);
        }
    }

    
    /**
     * Parses an XML file and load the content of the file in a ZeusRepository.
     *
     * @param config the parsed file.
     * @return the Respository containing the descriptions.
     */
    protected RepositoryZeus parseFile(Launcher config) {
        RepositoryZeus repository = new RepositoryZeus();
        parseFile(repository,config);
        return repository;   
    }
    
    /**
     * Parses an XML file and load the content of the file in a ZeusRepository.
     *
     * @param config the parsed file.
     * @param repository the Respository containing the descriptions.
     */
    protected void parseFile(RepositoryZeus repository, Launcher config) {    
        TraceSystem.get("parser").info("Zeus Parsing for "+config+" ...");
        if (config.getIncludeList()!=null) {
            for(Iterator i = config.getIncludeList().iterator() ; i.hasNext() ;) {
                Include incl = (Include)i.next();            
                if ( !parsed_files_.contains(incl.getUrl()) ) {
                    parsed_files_.add(incl.getUrl());
                    parseFile(repository,readFile(incl.getUrl()));
                }
            }
        }

        if (config.getClasspathList()!=null) {
            for(Iterator i = config.getClasspathList().iterator() ; i.hasNext() ; ) {
                Classpath c = (Classpath)i.next();
                TraceSystem.get("parser").debug("Adding classpath "+c.getId()+" ...");
                repository.addDescription(c.getId(),c);
            }
        }

        if (config.getArgumentsList()!=null) {
            for(Iterator i = config.getArgumentsList().iterator() ; i.hasNext() ; ) {
                Arguments a = (Arguments)i.next();              
                TraceSystem.get("parser").debug("Adding argument "+a.getId()+" ...");
                repository.addDescription(a.getId(),a);
            }       
        }

        if (config.getPropertiesList()!=null) {
            for(Iterator i = config.getPropertiesList().iterator() ; i.hasNext() ; ) {
                Properties p = (Properties)i.next();
                TraceSystem.get("parser").debug("Adding property "+p.getId()+" ...");
                repository.addDescription(p.getId(),p);
            }
        }

        if (config.getRunList()!=null) {
            for(Iterator i = config.getRunList().iterator() ; i.hasNext() ; ) {
                Run r = (Run)i.next();
                TraceSystem.get("parser").debug("Adding run "+r.getId()+" ...");
                repository.addDescription(r.getId(), r);
            }
        }

        if (config.getContextList()!=null) {
            for(Iterator i = config.getContextList().iterator() ; i.hasNext() ; ) {
                Context c = (Context)i.next();
                TraceSystem.get("parser").debug("Adding context "+c.getId());
                repository.addDescription(c.getId(), c);
            }
        }
    }


    /**
     * Loads an XML file.
     *
     * @param url the url of the file to load.
     */
    public Repository load(String url) {
        return parseFile(readFile(url));
    }
}
