/*====================================================================

ObjectWeb Util Ref Package.
Copyright (C) 2004 INRIA & USTL - LIFL - GOAL
Contact: architecture@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Philippe Merle.
Contributor(s): ______________________________________.

--------------------------------------------------------------------
$Id: Reference.java,v 1.1 2004/02/13 17:46:08 rouvoy Exp $
====================================================================*/

package org.objectweb.util.ref.api;

/**
 * Base interface for all Reference objects.
 *
 * A Reference object maintains an association between
 * the owner of the reference and the target of the reference.
 *
 * @author <a href="mailto:Philippe.Merle@lifl.fr">Philippe Merle</a>
 * @version 0.1
 */
public interface Reference
{
    /**
     * Obtains the owner of the reference.
     *
     * @return The owner of the reference.
     */
    public Referencable
    getOwner();

    /**
     * Sets the owner of the reference.
     *
     * @param ref The owner of the reference.
     */
    public void
    setOwner(Referencable ref);

    /**
     * Obtains the target of the reference.
     *
     * @return The target of the reference.
     */
    public Referencable
    getTarget();

    /**
     * Sets the target of the reference.
     *
     * @param ref The target of the reference.
     */
    public void
    setTarget(Referencable ref);

    /**
     * Cuts the reference.
     */
    public void
    cutIt();
}
