/*====================================================================

 ObjectWeb GoTM project - http://gotm.objectweb.org
 Contact: gotm@objectweb.org

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 USA

 Initial developer(s): Romain Rouvoy.
 Contributor(s): ______________________________________.

 ---------------------------------------------------------------------
 $Id: BasicReleaseInfo.java,v 1.1 2004/02/27 19:07:20 rouvoy Exp $
 ====================================================================*/

package org.objectweb.util.release;

/**
 * Basic Implementation of the Release Info.
 * @author <a href="mailto:Romain.Rouvoy@lifl.fr">Romain Rouvoy</a>
 * @version 0.1
 */
public class BasicReleaseInfo implements ReleaseInfo {

    protected String nameLong;
    protected String nameShort;
    
    protected short[] versionNumber = {1,0};
    protected short[] specVersionNumber = {1,0};
    
    
    /**
     * Defines the long version of the name.
     * @param nameLong The nameLong to set.
     */
    protected void setNameLong(String nameLong) {
        this.nameLong = nameLong;
    }

    /**
     * Defines the short version of the name.
     * @param nameShort The nameShort to set.
     */
    protected void setNameShort(String nameShort) {
        this.nameShort = nameShort;
    }

    /**
     * Defines the Specification Version Number.
     * @param specVersionNumber The specVersionNumber to set.
     */
    protected void setSpecVersionNumber(short[] specVersionNumber) {
        this.specVersionNumber = specVersionNumber;
    }

    /**
     * Defines the Implementation Version Number.
     * @param versionNumber The versionNumber to set.
     */
    protected void setVersionNumber(short[] versionNumber) {
        this.versionNumber = versionNumber;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getNameLong()
     */
    public String getNameLong() {
        return this.nameLong;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getNameShort()
     */
    public String getNameShort() {
        return this.nameShort;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getVersionNumber()
     */
    public short[] getVersionNumber() {
        return this.versionNumber;
    }

    /**
     * Convert a short array into a string using the tag separator.
     * @param number the short array to convert.
     * @param tag the tag to use in the string for separating numbers.
     * @return the resulting string (number[0]+tag+number[1]+tag+ ... +tag+number[length-1]).
     */
    protected static String toString(short[] number, String tag){
        StringBuffer buffer = new StringBuffer();
        buffer.append(number[0]);
        for (int i=1;i<number.length;i++) {
            buffer.append(tag+number[i]);
        }
        return buffer.toString();
    }
    
    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getVersion()
     */
    public String getVersion() {
        return toString(getVersionNumber(),".");
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getSpecVersionNumber()
     */
    public short[] getSpecVersionNumber() {
        return this.specVersionNumber;
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getSpecVersion()
     */
    public String getSpecVersion() {
        return toString(getSpecVersionNumber(),".");
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getRelease()
     */
    public String getRelease() {
        return getNameLong()+" Release "+getVersion();
    }

    /* (non-Javadoc)
     * @see org.objectweb.util.release.Release#getReleaseTag()
     */
    public String getReleaseTag() {
        return getNameLong()+"_"+toString(getVersionNumber(),"_");
    }
}
