/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jerome Offroy.
Contributor(s): ______________________________________.

====================================================================*/

/* TO DO verify|make compatibility with PocketPC */

#include "stdafx.h"

	HANDLE		theProcessToKill;
	CHAR        pname[MAX_PATH];  /* MAX_PATH define in windef.h */

void Usage();
void error(char *id, const char *label);
int handlingArg(char * arg);
int testPid(char *pid);
int parseArg(int argc, TCHAR* argv[]);

/*************************************************
 * kill.exe                                      *
 * Usage : kill.exe pid|FpidFile|[--help|-?|/?] *
 *                                               *
 * kill  process with its pid                    *
 *************************************************/
int main(int argc, char* argv[]){
	int nRetCode = 0;

	nRetCode = parseArg(argc, argv);			
	return nRetCode;
}

/********************
 * internal methods *
 ********************/

void Usage(){ fprintf(stderr,"Usage : kill PID|FpidFile\n"); } /* show usage */
void error(char *id, const char *label){ fprintf(stderr,"[ERROR] %s %s\n",id,label); } /* error method */
int handlingArg(char * arg);

/* execute kill action on specific target arg*/
int handlingArg(char * arg){
	int result;
	unsigned long pid;
	
	pid = atoi(arg);
	theProcessToKill = OpenProcess(THREAD_TERMINATE,FALSE,pid);
	result = TerminateProcess(theProcessToKill,1);
	Sleep(1000); /* Wait for resource freeing */
	return result; /* result != 0 if success */
		
}

/************************************** 
 *	function to test parameter        *
 *	return  0 : pattern found         *
 *		   >0 : pid found             *
 *		   <0 : negative pid found    *
 **************************************/
int testPid(char *pid){
	UCHAR       ch;
	int			idx    = 0;
	int			TmpPid = 0;
	char        *p     = pname;
		
	*p = '\0';
	ch = pid[idx];
	
	/* Look for a negative PID */
	if (ch == '-' && isdigit(pid[idx+1]) ) { 
		ch = pid[++idx]; 
		while (isdigit(ch)){ 
			TmpPid = TmpPid * 10 - ( ch - '0' ); 
			ch = pid[++idx]; 
       } 
       return TmpPid; /* found "kill -pid" */
    } 


    /* Look for a postive PID */
    if (isdigit(ch)){ 
       while (isdigit(ch)){ 
          TmpPid = TmpPid * 10 + ( ch - '0' ); 
		  ch = pid[++idx]; 
	   } 
       return TmpPid;  /* found "kill pid" */
    } 
  
    /* Look for a pattern */
    while (ch){ 
       *p++ = ch; 
	   ch = pid[++idx]; 
    } 
    *p = '\0'; 
	return 0;  /* found "kill pattern" or "kill F=pidFile" so we're done */

}

/******************************
 * function to test parameter *
 ******************************/
int parseArg(int argc, TCHAR* argv[]){
	int i,result,idx;
	char buf[80],c;
	FILE *in;

	if (argc < 2) { Usage();exit(-1); }
	for (i = 1 ; i < argc ; i++){
		result = testPid(argv[i]);
		if (result == 0) {
			if (strncmp(pname,"F",1)==0 ){
				/* pidFile handling */
				in = fopen(pname+1,"r");
				if( in == NULL) {error(pname+1,"file doesn't exist");exit(2);}
				c = fgetc(in);
				idx = 0;
				while (c != '10' && c != EOF){
					buf[idx++] = c;
					c = fgetc(in);
				}
				buf[idx] = '\0';
				result = handlingArg(buf);
				if ( result == 0) error(_strrev(_strrev(buf)+1),"Not kill");
			}else if(strcmp("--help",pname) == 0 || strcmp("/?",pname) == 0 || strcmp("-?",pname) == 0){
				/* show usage */
				Usage();	
			}else{
				/* pattern management */
				error(pname,"gestion des pattern non implemente\n");
			}
		}else {
			/* kill pid */
			result = handlingArg((char *)argv[i]);
			if ( result == 0) error(argv[i],"don't proceed");
		}
	}
	return 0;
}
