/*====================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2003 INRIA & USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Christophe Demarey.
Contributor(s): ______________________________________.

====================================================================*/

package org.objectweb.openccm.services.pss.common.lib;


/**
 * ConnectorRegistry is used to register Connectors.
 * It implements the org.omg.CosPersistentState.ConnectorRegistry interface.
 *
 * @author <a href="mailto:Christophe.Demarey@lifl.fr">Christophe Demarey</a>
 *
 * @version 0.1
 */

public class ConnectorRegistry
     extends org.omg.CORBA.LocalObject
  implements org.omg.CosPersistentState.ConnectorRegistry
{
    // ==================================================================
    //
    // Internal state.
    //
    // ==================================================================

    /**
     * Registered connectors.
     */
    protected java.util.Map _connectors;

    // ==================================================================
    //
    // Constructor.
    //
    // ==================================================================

    /**
     * The default constructor.
     */
    public ConnectorRegistry()
    {
        _connectors = new java.util.HashMap();
    }

    // ==================================================================
    //
    // Internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Public methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Methods for org.omg.CosPersistentState.ConnectorRegistry
    //
    // ==================================================================

    /**
     * Find a previously registered connector.
     */
    public org.omg.CosPersistentState.Connector
    find_connector(String implementation_id)
    throws org.omg.CosPersistentState.NotFound
    {
        org.omg.CosPersistentState.Connector connector = null;

        connector = (org.omg.CosPersistentState.Connector) _connectors.get(implementation_id.toLowerCase());
        if (connector == null)
            throw new org.omg.CosPersistentState.NotFound();
        return connector;
    }

    /**
     * Register a connector.
     */
    public void
    register_connector(org.omg.CosPersistentState.Connector c)
    {
        _connectors.put(c.implementation_id().toLowerCase(), c);
    }

    /**
     * Unregister a connector.
     */
    public void
    unregister_connector(String implementation_id)
    throws org.omg.CosPersistentState.NotFound
    {
        org.omg.CosPersistentState.Connector connector = null;

        connector = (org.omg.CosPersistentState.Connector) _connectors.remove(implementation_id.toLowerCase());

        if (connector == null)
            throw new org.omg.CosPersistentState.NotFound();
    }
}
